aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
20 files changed, 190 insertions, 194 deletions
diff --git a/Makefile b/Makefile
index 9834ddf4..292ead3f 100644
--- a/Makefile
+++ b/Makefile
@@ -62,7 +62,7 @@ pkg/bindata/bindata.go: $(DATA_FILES)
less: public/css/gogs.css
public/css/gogs.css: $(LESS_FILES)
- lessc $< >$@
+ @type lessc >/dev/null 2>&1 && lessc $< >$@ || echo "lessc command not found, skipped."
clean:
go clean -i ./...
diff --git a/cmd/backup.go b/cmd/backup.go
index ad635a4d..0adde979 100644
--- a/cmd/backup.go
+++ b/cmd/backup.go
@@ -100,7 +100,7 @@ func runBackup(c *cli.Context) error {
// Data files
if !c.Bool("database-only") {
- for _, dir := range []string{"attachments", "avatars"} {
+ for _, dir := range []string{"attachments", "avatars", "repo-avatars"} {
dirPath := path.Join(setting.AppDataPath, dir)
if !com.IsDir(dirPath) {
continue
diff --git a/cmd/restore.go b/cmd/restore.go
index 9591b044..70ce948e 100644
--- a/cmd/restore.go
+++ b/cmd/restore.go
@@ -115,7 +115,7 @@ func runRestore(c *cli.Context) error {
// Data files
if !c.Bool("database-only") {
os.MkdirAll(setting.AppDataPath, os.ModePerm)
- for _, dir := range []string{"attachments", "avatars"} {
+ for _, dir := range []string{"attachments", "avatars", "repo-avatars"} {
// Skip if backup archive does not have corresponding data
srcPath := path.Join(archivePath, "data", dir)
if !com.IsDir(srcPath) {
diff --git a/cmd/web.go b/cmd/web.go
index cd4e49cb..cb17543c 100644
--- a/cmd/web.go
+++ b/cmd/web.go
@@ -64,7 +64,7 @@ func checkVersion() {
if err != nil {
log.Fatal(2, "Fail to read 'templates/.VERSION': %v", err)
}
- tplVer := string(data)
+ tplVer := strings.TrimSpace(string(data))
if tplVer != setting.AppVer {
if version.Compare(tplVer, setting.AppVer, ">") {
log.Fatal(2, "Binary version is lower than template file version, did you forget to recompile Gogs?")
@@ -96,14 +96,14 @@ func newMacaron() *macaron.Macaron {
m.Use(macaron.Static(
setting.AvatarUploadPath,
macaron.StaticOptions{
- Prefix: "avatars",
+ Prefix: models.USER_AVATAR_URL_PREFIX,
SkipLogging: setting.DisableRouterLog,
},
))
m.Use(macaron.Static(
setting.RepositoryAvatarUploadPath,
macaron.StaticOptions{
- Prefix: "repo-avatars",
+ Prefix: models.REPO_AVATAR_URL_PREFIX,
SkipLogging: setting.DisableRouterLog,
},
))
diff --git a/gogs.go b/gogs.go
index e5f77322..8b1129f2 100644
--- a/gogs.go
+++ b/gogs.go
@@ -16,7 +16,7 @@ import (
"github.com/gogs/gogs/pkg/setting"
)
-const APP_VER = "0.11.57.0617"
+const APP_VER = "0.11.58.0617"
func init() {
setting.AppVer = APP_VER
diff --git a/models/access.go b/models/access.go
index c10c9750..f9c0408c 100644
--- a/models/access.go
+++ b/models/access.go
@@ -237,6 +237,6 @@ func (repo *Repository) recalculateAccesses(e Engine) error {
}
// RecalculateAccesses recalculates all accesses for repository.
-func (r *Repository) RecalculateAccesses() error {
- return r.recalculateAccesses(x)
+func (repo *Repository) RecalculateAccesses() error {
+ return repo.recalculateAccesses(x)
}
diff --git a/models/user.go b/models/user.go
index ab836b49..7e014df4 100644
--- a/models/user.go
+++ b/models/user.go
@@ -35,6 +35,9 @@ import (
"github.com/gogs/gogs/pkg/tool"
)
+// USER_AVATAR_URL_PREFIX is used to identify a URL is to access user avatar.
+const USER_AVATAR_URL_PREFIX = "avatars"
+
type UserType int
const (
@@ -257,7 +260,7 @@ func (u *User) RelAvatarLink() string {
if !com.IsExist(u.CustomAvatarPath()) {
return defaultImgUrl
}
- return setting.AppSubURL + "/avatars/" + com.ToStr(u.ID)
+ return fmt.Sprintf("%s/%s/%d", setting.AppSubURL, USER_AVATAR_URL_PREFIX, u.ID)
case setting.DisableGravatar, setting.OfflineMode:
if !com.IsExist(u.CustomAvatarPath()) {
if err := u.GenerateRandomAvatar(); err != nil {
@@ -265,7 +268,7 @@ func (u *User) RelAvatarLink() string {
}
}
- return setting.AppSubURL + "/avatars/" + com.ToStr(u.ID)
+ return fmt.Sprintf("%s/%s/%d", setting.AppSubURL, USER_AVATAR_URL_PREFIX, u.ID)
}
return tool.AvatarLink(u.AvatarEmail)
}
@@ -330,50 +333,37 @@ func (u *User) ValidatePassword(passwd string) bool {
}
// UploadAvatar saves custom avatar for user.
-// FIXME: split uploads to different subdirs in case we have massive users.
+// FIXME: split uploads to different subdirs in case we have massive number of users.
func (u *User) UploadAvatar(data []byte) error {
img, _, err := image.Decode(bytes.NewReader(data))
if err != nil {
- return fmt.Errorf("Decode: %v", err)
- }
-
- m := resize.Resize(avatar.AVATAR_SIZE, avatar.AVATAR_SIZE, img, resize.NearestNeighbor)
-
- sess := x.NewSession()
- defer sess.Close()
- if err = sess.Begin(); err != nil {
- return err
- }
-
- u.UseCustomAvatar = true
- if err = updateUser(sess, u); err != nil {
- return fmt.Errorf("updateUser: %v", err)
+ return fmt.Errorf("decode image: %v", err)
}
os.MkdirAll(setting.AvatarUploadPath, os.ModePerm)
fw, err := os.Create(u.CustomAvatarPath())
if err != nil {
- return fmt.Errorf("Create: %v", err)
+ return fmt.Errorf("create custom avatar directory: %v", err)
}
defer fw.Close()
+ m := resize.Resize(avatar.AVATAR_SIZE, avatar.AVATAR_SIZE, img, resize.NearestNeighbor)
if err = png.Encode(fw, m); err != nil {
- return fmt.Errorf("Encode: %v", err)
+ return fmt.Errorf("encode image: %v", err)
}
- return sess.Commit()
+ return nil
}
// DeleteAvatar deletes the user's custom avatar.
func (u *User) DeleteAvatar() error {
log.Trace("DeleteAvatar [%d]: %s", u.ID, u.CustomAvatarPath())
- os.Remove(u.CustomAvatarPath())
+ if err := os.Remove(u.CustomAvatarPath()); err != nil {
+ return err
+ }
u.UseCustomAvatar = false
- if err := UpdateUser(u); err != nil {
- return fmt.Errorf("UpdateUser: %v", err)
- }
- return nil
+ return UpdateUser(u)
}
// IsAdminOfRepo returns true if user has admin or higher access of repository.
diff --git a/pkg/bindata/bindata.go b/pkg/bindata/bindata.go
index f56eb131..bdfb0bb9 100644
--- a/pkg/bindata/bindata.go
+++ b/pkg/bindata/bindata.go
@@ -300,7 +300,7 @@ func (fi bindataFileInfo) Sys() interface{} {
return nil
}
-var _confAppIni = []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xe4\x7b\xdd\x8f\xdc\xc8\x76\xdf\x7b\xfd\x15\x67\xe7\x66\xb3\x92\xc1\xee\xf9\xd2\xcc\x6a\x35\xb7\x2f\xb6\xd5\xcd\xe9\xa1\xd5\x5f\x4b\xb2\xf5\xb1\x82\x40\xd5\x90\xd5\xcd\xda\x61\xb3\x7a\x59\xc5\x19\xf5\x22\x30\x76\xe1\x07\x27\x41\xfc\x94\xc4\x46\x00\x23\x80\x11\x24\x06\x9c\x38\xb9\x46\x12\xe0\xfa\xe6\x1a\x79\x58\xfb\x5d\xfa\x1f\x8c\x7b\xed\x20\x81\xff\x85\xe0\x9c\x22\xbb\xd9\xd2\x48\x77\x6f\x90\x3c\x45\x02\xa6\xd9\x64\xd5\x61\xd5\xf9\xfc\x9d\x73\xaa\x7f\x04\x1f\x7d\xf4\x11\x8c\xdd\xc7\xae\x0f\xf4\x67\x34\xe9\x7b\xe7\xcf\x20\xbc\xf0\x02\x38\xf7\x86\x2e\x3e\x67\x76\xd4\x74\xe8\x76\x03\x17\x46\xdd\x47\x2e\xf4\x2e\xba\xe3\x81\x1b\xc0\x64\x0c\xbd\x89\xef\xbb\xc1\x74\x32\xee\x7b\xe3\x01\xf4\x66\x41\x38\x19\x41\x6f\x32\x3e\xf7\x06\x6f\x53\xf0\xce\xe1\xd9\x64\x06\x5d\xdf\x85\x69\xb7\xf7\xa8\x3b\xc0\x19\x53\x7f\xf2\xd8\xeb\xbb\xbe\xb3\xf3\x82\xc9\x13\xa4\x3c\x7d\x06\x93\x73\xf0\x42\xa2\xc1\xce\xa0\xbb\x5a\x41\xce\x97\x02\x4c\xca\x0d\xe8\x54\xdd\x68\x50\x39\x88\x6b\x51\xac\x61\xc5\x17\x02\x8c\x34\x99\x60\xdd\xe9\x34\x1a\x77\x47\x2e\x74\x60\xa0\x16\x9a\x9d\x41\x98\x0a\x3b\x53\xcd\xc1\xa4\x02\xf4\x5a\x1b\xb1\x84\x52\x8b\xc2\x12\x2b\xca\x5c\xdb\xc1\xfe\x6c\x1c\xcd\x02\xd7\x87\x0e\x2c\xa4\x61\x67\xe0\x4a\x93\x8a\x02\xf6\x12\x71\xbd\xe7\xc0\xde\xaa\x50\xc9\x1e\xa8\x02\xf6\x8c\xd0\x66\x8f\xc6\x8f\x26\x7d\x7c\x59\x22\xae\x19\x7b\xae\x45\x71\x2d\x8a\x17\x6c\xea\x4f\xc2\x49\x6f\x32\x84\x0e\xa4\xc6\xac\x58\x7f\x32\xea\x7a\x63\xe8\x40\xa6\x62\x9e\xa5\x4a\x1b\xe6\x4f\x26\x61\x34\xf3\x71\xc8\xc7\x77\xea\xf1\x77\xf5\x83\xfd\xfd\x8f\xef\xd8\xe1\x77\xf5\x83\x8f\xef\x5c\x84\xe1\x34\x9a\x4e\xfc\xf0\xae\xde\x67\xf4\xa5\xdb\xef\xe3\x02\x0f\xda\xf4\x9f\x6d\x06\x40\x07\x8e\x0f\x0e\x0e\xd8\x19\x4c\x45\xb1\x94\x5a\x4b\x95\xc3\x5c\x15\x50\xe6\xf2\x15\x68\x15\x5f\x09\xc3\x66\x63\xef\x69\x14\x4c\x7a\x8f\xdc\x30\x9a\xba\xfe\xc8\x0b\x02\x6f\x82\x0b\x3b\x3d\x3d\x65\x67\x30\xc4\xe5\xc1\x9d\xfe\xe8\xcb\xbb\x80\x6b\xc3\xe9\xc8\x19\xb8\x51\xc5\x95\x28\x34\xdc\xd1\x65\x9c\x02\xd7\x10\x04\x17\x50\xae\x12\x6e\xc4\x5d\xe0\x71\x2c\xb4\x96\xf9\x02\x6e\xc4\x25\x20\x0f\x64\x2c\xda\xec\x0c\xbc\x1c\x96\x4a\x1b\x88\xb9\x16\x1a\xd6\xaa\x84\x44\x41\xae\x0c\xe4\x42\x24\x60\x14\xc4\x29\xcf\x51\x74\xa9\x80\x44\xcc\x79\x99\x19\xb8\xe6\x59\x49\x93\xbb\x99\x11\x05\x48\x03\x2a\xcf\xd6\x20\xe7\x38\xbf\xa0\xf7\x5a\x2e\x43\xae\x12\x01\x52\x13\x41\x12\x2c\x0a\x99\x6b\x40\x8e\xd0\xc3\x36\x1b\x4e\x7a\xdd\x61\xf4\x21\x56\x6f\x58\xfa\x2e\xb7\xcf\xa0\x2f\x35\xbf\xcc\x04\xbd\x74\x2e\xb8\x29\x0b\x01\x37\xa9\xc8\xe9\x95\xfc\x9a\xcb\x0c\x1f\xb3\xbe\x17\x74\x1f\x0e\xdd\x08\x87\x75\x60\xce\x33\x2d\xd8\x19\x3c\x49\x05\x29\x4f\xa9\x05\x5c\x96\x32\x33\x32\x6f\xae\x5e\xe1\x06\x4c\x9b\x05\x61\xd7\x0f\x71\x6a\x14\xb8\xfe\x63\xd2\xbd\x9a\x42\x5f\x2d\xb9\xcc\x2b\xb5\x57\x70\x29\x40\xbc\x5a\x29\x2d\x12\xa8\x48\xc5\x99\xca\x05\x0a\x8a\xe1\xfc\x8d\x92\x6d\x15\x08\x95\x41\x15\x06\xf2\x72\x79\x89\xea\xfe\xeb\x89\x54\x9a\x74\x74\xc4\xce\x60\x2c\x0c\xca\x1d\x64\x6e\x44\x31\xe7\xf1\xad\xfb\xc8\xa4\x36\x22\x47\x63\xa4\xf9\x43\x2f\x08\xdd\x71\x74\x31\x09\xc2\x86\x92\xee\x2e\xe3\x07\x53\xa9\x16\xf3\xf1\x9d\x7a\x65\xb4\x23\x5f\x29\x03\x2b\x6e\x52\xb4\x68\xa4\x91\xc8\x42\xc4\x46\x15\x6b\x67\xa3\x45\x52\xc3\x27\xbf\xb3\xdf\xd6\x3a\xfd\xc4\x81\xcb\xd2\x90\xf2\xa5\xfc\x9a\x18\x89\x12\xf9\x64\x3f\x55\x4b\xb1\xbf\x90\xc6\x8e\x6a\xd3\x7b\x49\x53\xa6\xdd\xf0\x02\x3a\xa4\xbe\x89\x8c\xb9\x21\x99\x93\x28\x8d\x82\x42\xdc\x14\xd2\x08\xe0\xa5\x49\x55\x21\xbf\x11\x49\x74\x25\xd6\x1a\xd0\x29\x19\x5e\x18\x07\xe4\x22\x57\x85\x48\xac\xa2\xdc\x2e\x7c\xe6\xbb\x4f\x7c\x2f\x74\xa3\xee\x2c\xbc\x98\xf8\xde\x97\x6e\x3f\x7a\xe4\x3e\x0b\xa2\x6e\x18\x91\x3e\x34\x94\xa0\x97\x2a\xa5\xad\x89\xc4\x72\x95\xa2\x11\x1a\x05\xba\x5c\xad\x90\xa3\x68\xa0\x24\x44\x95\xe7\x22\x36\x52\xe5\x9a\x6d\x75\x29\xea\x79\xd3\x0b\xd7\x0f\xa0\x03\x5c\xe8\xc3\xa3\xfb\xad\xd8\x14\x0e\x5d\x7f\x76\xb4\xb9\x3e\x3a\x39\xdd\xde\x3f\xba\xdf\x5a\xc4\xcb\xcf\xd5\x4a\xe4\x5a\xa7\xed\x58\x2d\x1d\xe0\x45\x3c\x57\x65\x71\x74\x72\xba\xb9\x3e\x3c\xba\x4f\xf6\x51\x31\x9e\x6c\xb9\x10\xc8\x2b\x23\x96\x2b\x55\xf0\x62\x0d\x73\x99\x09\x6d\xd9\x80\xee\x12\x56\xe5\x65\x26\xe3\x2b\xb8\x12\x6b\x28\xc9\x5d\x68\x9d\xb6\xae\xc4\x7a\x21\x72\x87\x9d\x35\x65\x57\xf9\xe8\x2d\xad\x8d\x88\xad\x9c\x1e\xb9\xcf\xa2\xd0\x0d\x1a\xb2\x9a\xa2\x3e\x20\x63\xb6\x24\x77\x94\x61\x7b\xff\x13\xe0\x79\x02\x99\xc0\x28\x22\xb2\x0c\xe6\x32\x4f\x40\x95\x06\x6e\x52\x19\xa7\x80\xc6\x80\xbb\xe1\x59\xb6\x79\xd7\x00\x75\x91\xde\xd4\xa0\xff\x1e\x05\x89\x53\x11\x5f\xc1\x52\xe6\x72\x59\x2e\x69\xaf\x5a\x7e\x23\xe0\x46\x9a\x14\x62\x55\x14\x42\xaf\x54\x9e\xe0\xee\xcd\x7a\x25\xd8\xc8\x1b\x7b\xa3\xd9\x88\x76\x14\x78\x5f\xba\x51\xef\xc2\xed\x3d\x6a\x3a\x81\xca\x07\xf5\xfa\x63\x8c\x76\x39\x9a\x6d\x15\x88\x96\x2a\x11\x6c\x72\x7e\x3e\xf4\xc6\x6e\x1d\x87\xec\xb4\xda\x23\xf9\x93\x59\xe8\xfa\xd1\x70\x32\x68\x50\x1c\x88\x5c\x14\xb8\x6a\x6d\xc4\x4a\x3f\x60\x67\xf0\x0f\xa0\xbd\xbf\x40\x37\x1f\x8b\xc2\x40\x2b\xe6\x1d\x53\x94\x02\x5a\x49\x59\x70\xd4\xa9\xce\xfd\x4f\x4f\x0f\xd2\x83\xe5\x81\x86\x16\x06\xaf\xce\x72\x8d\x1f\x6d\xf1\x8a\x2f\x57\x99\x40\x2d\x61\x67\xec\x0c\x26\x05\xcc\x0b\xb5\x04\x0e\xed\xd5\xfc\x15\x29\x00\x79\x9b\xc2\x88\xc4\x3e\x41\x35\x7e\x22\xf3\x04\xc3\x37\xbe\x4c\xce\x2d\x03\xb5\x51\x85\x80\x3b\x89\x62\x67\xe4\x5c\xe7\xaa\x58\x08\x83\xfc\xb4\xf3\x69\xe2\xaa\x90\xd7\x38\xf8\x4a\xac\xef\xda\x65\x5b\x35\xcd\x60\x75\x15\xeb\xc3\x23\x68\xc9\x9c\xa8\xd2\xdb\x5b\x28\x53\xfb\x4d\x2c\xa1\x95\x2b\xb4\xd3\x1f\x36\xeb\x4a\xac\xeb\x49\xf8\x40\xe3\x45\x22\x34\xeb\xb9\x7e\x18\x11\xb2\xe9\x40\x5c\x6a\xa3\x96\xfb\x18\xde\xf5\x7e\xfd\x1a\x86\x62\xbc\x6d\x40\x45\x91\xc2\x5a\xa6\x6e\x44\x02\xe1\x30\x80\x6b\x51\x50\x94\xa6\x98\xa7\x1f\x40\x10\x0c\x8f\x0f\x1c\x7c\x74\x58\x7d\x1c\xda\x8f\x23\x16\x0e\x83\x68\xe4\x8d\xa3\xc7\xae\x5f\x45\x6c\x1a\x85\xd0\x68\xb6\x5a\xa1\x07\x15\xd7\x22\x23\x8c\x23\x96\xab\x0c\xd9\x84\x6a\xae\x0d\x37\x32\xb6\x92\x40\x97\xb9\x6b\x66\xc4\x54\x34\x9c\x9b\x54\x14\xc2\x46\x7a\xa9\x41\xbc\x12\x71\x69\x44\x82\xb1\x29\xf4\x7a\x6f\x79\xc5\x7e\x35\x9f\x26\xa2\xff\x41\x68\x96\x70\xc3\x09\x7b\xf5\xbb\x61\xb7\xb6\x15\xba\x49\xd0\x2d\x43\x29\xe3\x4e\xed\x2a\x07\x5f\x7a\xd3\xda\x85\x31\x77\x4c\xaa\x4a\xf7\xb6\x4a\x3a\xe4\xd6\x48\x08\xda\xcd\x29\x58\xe6\xad\x4c\x2d\x16\x22\x21\xe8\xa6\x1d\x88\x79\x8e\xe1\x6c\x0f\x1d\xb9\x45\x65\xe2\xd5\x2a\x53\x85\xd8\x63\xc3\x2e\x61\xd2\x68\xda\x1d\xa0\x28\x70\x04\x63\xcf\x0b\xb1\x52\x5a\xa2\x17\x79\xb1\x13\x46\x90\x3c\x2a\x20\xbe\x6f\x33\x46\x0a\xfd\x89\xa6\x2d\xec\x38\x92\xbd\xdf\xd9\xff\x31\xbe\x1f\x83\xf2\x4f\xc8\x68\x5a\xcd\x29\x7b\x84\xeb\x88\x4f\x88\x3b\x75\x5c\xc8\x95\x21\x4b\xaf\x23\x5d\xb5\x6d\xed\x80\x56\x4b\x61\xe4\x52\x68\x88\x55\x99\x25\xb4\x17\x9d\xee\xb1\xa0\xe7\x7b\xd3\x30\x0a\x9f\x4d\x71\xed\x97\x5c\xa7\x0d\xae\x77\xc7\x81\x87\xb0\xa9\xd0\xc2\x7a\x7f\x9e\x43\x99\x17\x22\x56\x8b\x1c\xa3\x51\xfd\x8c\xe1\xc0\xa8\x77\xd1\xf5\x03\xd7\xae\xe7\x5c\x15\xb1\xa8\x00\x73\x2e\x6e\xb6\x3b\x5d\x57\xb8\xa0\x32\x2f\x76\x3e\xf1\x7b\x6e\x34\xf5\xbd\xc7\xdd\xd0\x6d\xfa\x8d\x4c\x5d\xf2\x0c\x96\xfc\x15\xb9\x36\xf2\xf7\x24\x53\xb9\x44\x94\x36\x6f\x52\x5c\x59\xe0\x53\x38\xd0\x3a\x84\xa5\xe0\x39\xc2\x34\x3b\x92\x8d\xba\x4f\xa3\x9e\xef\x76\x43\x6f\x32\x8e\x86\xde\xc8\xc3\x70\xd7\x3a\x64\x67\x30\x92\x45\x81\xb2\x58\xe7\x31\x7c\x5d\x8a\x52\x40\x26\xf2\x85\x49\x1d\x90\x39\xbe\x4e\x0b\xc4\x81\xcb\xed\x28\x0a\x22\x18\x76\x35\x20\x92\x94\xf9\x82\x8d\x3c\xdf\x9f\xf8\xd1\x17\x33\x77\xe6\x46\x43\x77\x3c\x20\x55\x3c\xac\x90\x31\x37\x71\x6a\xa3\xd1\xfb\xe9\xaf\xca\x2c\x83\x42\x7c\x5d\x52\xd0\xda\xcc\xb8\xe5\x5d\xd3\xd9\x70\x18\xf9\xee\x17\x33\x0c\x45\xef\x79\x63\x21\xe6\xa2\x40\x3c\x30\x94\xb1\xc8\x11\x07\x1b\x05\xab\x0c\xd1\x14\xb7\x6e\xcd\xa8\x55\x9d\x9b\x20\x0c\x42\xe0\x85\x88\x6f\x59\x6a\x03\x4b\x7a\x3d\x99\x2f\xc1\x40\x74\x55\x2a\x9f\xef\x67\x96\x18\x6a\x7d\xe5\x67\x9a\xb7\xd9\xd4\x77\xcf\x5d\xdf\x77\xfb\xd1\xd0\xeb\xb9\xe3\xc0\x45\x08\xd0\x5d\xf1\x38\x15\xf5\x3a\xe0\xa8\x7d\xe0\x20\xef\xab\xef\x8d\x50\xc3\x2f\x65\x26\x0d\xa9\x05\x41\x3f\x1e\x1b\x1b\xbf\x9a\x9a\x0e\x97\x6b\x8b\xb4\x57\x85\x32\x2a\x56\xd9\x26\xe8\x10\x88\x1e\x78\x4d\x10\xe3\xe6\x6f\x13\x5e\xca\x05\xc5\xa0\x86\xce\x5c\xae\x6d\x7a\x64\x1d\x55\xe5\x16\x2c\x82\x47\x87\x12\x8d\xbc\x81\x4f\x4a\xd3\x44\x47\x2a\x8f\xcb\xa2\x10\x79\xbc\x46\xeb\x2c\xb5\xcd\x2b\x0a\x61\x0a\x29\xae\x05\xc4\x6a\xb9\x94\x46\x83\xcc\xe7\xaa\x58\x92\xbe\xb6\x21\x4c\xa5\x86\x6b\x5e\x48\x5a\x54\x22\xe6\x32\x47\x5a\x28\x80\x5a\xb9\x2b\xa4\x8a\x62\xe1\xfa\x4a\xdb\x44\xb1\x72\x38\x45\x99\xd7\xa2\xa3\x94\x03\x6d\xb8\x0d\x33\x5d\xf2\x2c\x5b\x3b\x78\x9f\x9d\x59\x97\x0e\x89\x58\x09\x44\x17\x73\x48\xd5\x0d\x2c\x79\xbe\x86\xde\x74\xa6\xe1\x4e\xac\x0a\xa1\xef\x6e\x50\x69\x1b\x3c\xab\x00\x76\x1a\x22\x20\x1b\xfd\xbe\x11\x05\x86\x44\xca\xe2\x12\x34\xa7\xc1\x64\x10\xc0\x8d\xcc\x32\x44\xa0\x0a\x77\x84\x48\x65\x0d\x89\x30\x22\xb6\x8b\xda\xae\x9d\xde\x45\x69\x53\x05\xa8\xf0\x5d\xac\x37\x19\x8d\xbc\x30\x88\xce\xdd\xb0\x77\x11\xf5\x26\xe3\xde\xcc\xf7\xdd\x71\xef\x19\x02\xf6\xad\xb0\x0a\x81\x6f\x24\x90\x41\x8e\xa6\xe0\x37\xa4\x88\xb5\x64\xfc\xee\x13\x0a\x75\x91\xef\x8e\xfb\xae\xbf\x0b\x40\x9a\xce\xb6\x2d\x12\xfc\x44\x9f\x3b\x94\x9a\x3c\x45\x85\x0c\x10\xf2\x23\x64\xdd\x24\xf5\xe8\x06\x09\xa5\x67\x32\x17\x70\x53\xf0\x15\x8a\x8e\x76\xd5\x53\x89\xa8\xfc\x83\xa5\x87\x39\x62\x20\x56\x9c\xd4\xa8\x41\x8b\x34\x95\x93\xe4\x79\x1b\x42\xb5\xa5\x55\x23\x52\x69\x52\x8c\xf2\x9b\x39\x0e\x7c\x55\x12\x3e\x35\xf5\x3c\x46\x90\xea\x89\xdf\x9d\x46\xee\xd3\xd0\x1d\x63\xc8\x45\x13\x6a\x9b\x57\xc6\x69\x2f\x13\xa7\xbd\xe4\xc5\x55\xa2\x6e\x72\xfc\x66\x3f\xae\x12\x04\xb1\x8f\x79\x26\x13\xbb\x3f\xe4\x5c\xb5\x35\xda\x13\x87\x55\x21\xae\xa5\xb8\x81\xee\xd4\x03\xae\xb5\x8a\x25\x47\x64\x44\x2b\x36\xa9\x58\x3a\x50\xa7\xd7\x7c\x25\xf7\xaf\x0f\xf7\xeb\xb7\xec\xec\xd5\xa2\x05\x34\x17\x5a\xab\x6e\xa3\x93\x21\xba\x86\x5f\x22\xbb\x90\x3f\x56\x6e\x37\x2a\xff\xc4\x56\x4b\xd0\xb1\x21\x1b\x77\x39\x0f\x89\x12\x1a\x87\x90\x9f\x41\xb7\xf1\xd8\x73\x9f\x90\x78\x49\xb4\x28\x53\xdc\x77\xbd\x8e\x5d\xb9\x96\xab\x4c\xf1\xe4\x45\x53\x65\x36\xc6\x4c\xef\xb1\x03\x74\xbb\x52\x99\x3e\x74\x00\x81\x65\x03\xae\xd7\x08\x5f\x66\xeb\x0a\x03\x56\x73\xe0\x4e\xd2\xc4\x19\x0b\x61\x34\xc4\x99\xe0\xb9\x48\x70\xe7\x16\xaa\xd4\xf5\x1f\x72\xcb\x77\x59\xe8\x8e\xa6\x4d\xec\xb1\x6f\x96\xab\xfd\x8a\x1e\x06\x40\x5c\x12\x86\xe2\x4a\x28\xbc\x10\xc0\x2b\x34\x66\x23\xa0\x1d\x2b\x12\x07\x44\x7b\xd1\x06\xb9\xe4\x0b\xb1\xff\xd5\x4a\x2c\xfe\x91\xbd\x5c\xe5\x8b\x36\x0c\x05\x0a\x53\x2c\x57\x66\x5d\x45\x36\x22\x02\x68\xdc\xf3\xfa\x15\xac\x3b\x1c\x4e\x9e\xb8\x7d\x8a\xe2\x01\xc5\xdf\x51\xe5\x5a\x28\x1d\x50\x73\x10\xbc\xf6\xec\x32\x87\xd1\x43\x66\x19\xde\x7d\x4a\x69\x00\x74\xe0\xb8\x31\x67\x6b\xd2\x56\x85\x29\xbc\xd2\x62\x29\x9a\xe2\x54\x14\xd3\x09\x55\xca\x8c\xe1\x71\xba\x14\xb9\x41\x27\x82\x61\x4b\x5b\xfb\x15\x19\x46\x38\x8d\x22\xa4\xab\x36\xdf\x8c\x7c\xd1\xa8\x57\x6c\xef\x6a\x62\x91\x20\xd9\x26\xed\x1a\x82\x50\x00\x7b\x89\x72\x7c\xf9\x1e\xb9\x12\x2c\xd9\x52\x79\x6b\x26\x49\xa6\xf1\xf8\x25\x6b\x8a\xac\xf1\x00\x13\x8a\x9c\x42\xdc\x52\x35\x45\x85\x12\xfc\x80\x84\xde\x66\x3d\xfc\xd6\xfe\x6f\x59\x56\xbe\xcb\xfa\xdd\xa5\x1d\x1f\x8d\x1e\xb2\xa6\x04\x8e\xaa\x79\xef\x67\xff\x2e\x81\xc3\x83\x1d\x71\x20\x3c\x7f\x5e\x9b\x4e\xc3\x4c\x52\x5e\x24\xd6\x2b\x5d\x16\x82\x5f\x6d\xcd\xb1\x76\xad\x17\x5d\x1f\x23\xf7\xd8\x8d\x1e\xfa\x6e\xb7\x99\x0d\xd6\x0e\xd4\x06\x7d\x98\xf9\xc3\x56\x10\xa7\x62\x79\x9b\x4e\x73\x8d\x2f\xb9\xaa\x52\x70\xeb\xce\x11\xc4\x8c\x6a\x63\x3e\x23\x49\x55\x49\x1c\x2c\xa4\x71\x96\x7c\x91\x0b\xc3\x6c\x29\x37\x9a\xf9\xc3\x28\xe8\x5d\xb8\xa3\x4a\x83\x7f\x88\xf7\xbe\xac\x03\x87\x48\xf6\xd1\x0f\xd9\x75\x34\x5e\xf9\x83\x5c\x76\x15\x7b\x2a\x7f\xbd\xaf\x1a\x1e\x8b\xeb\x8d\x37\xba\xc5\x6f\x93\x11\xed\xba\xec\xf7\x79\x6b\xc6\x9e\xeb\x25\x2f\xcc\x7a\xc5\x73\xa3\x5f\x34\x74\xd9\x32\xfb\xdc\xef\xf6\xc2\x8a\x08\x69\x77\xbf\x1b\x5c\xb8\x9b\x6f\xc3\x6e\xe8\x3e\x8d\x76\xef\x75\xc7\x83\xa1\xdb\x8f\xbe\x98\x4d\xc2\xed\x4d\xf6\x1c\x53\xc0\x17\x36\x36\x94\x36\x96\x76\xa9\x62\xda\xea\xa9\xdc\x14\x2a\x6b\x51\x4e\xd8\x9a\x14\x72\x21\x73\x48\x05\xa7\x48\xdf\x48\x3a\xa8\xc2\xa9\x30\x7c\x68\x91\x1b\xd6\xed\xf5\xdc\x20\xc0\xc8\x1d\xfa\x93\x61\x44\xfa\x1e\x4d\x7c\x6f\xe0\x8d\xa1\xc3\x6c\xb2\x80\xda\xb5\x51\x84\x6c\xa1\x0a\x69\xd2\xa5\xa6\x9c\xd0\xa4\x42\x16\x3b\x15\x0a\x8b\x82\xe1\x4e\xa9\x05\xe2\x75\xa3\x20\xa9\xa1\x20\x99\xdb\x5d\xf6\x5c\xeb\xb4\x5d\x4d\x89\xae\xc4\x3a\x42\x53\x42\xa6\xf5\x8f\x4e\x4e\x0e\x3f\x83\x0e\x1c\x9d\x9c\x32\xb7\xd7\x0f\xba\x00\xd5\x37\x9f\xae\xe9\xdb\xc1\xbd\xfb\xac\xbf\xf9\x7a\x78\x70\x74\x8f\xb1\xe7\x68\xef\x97\x5c\x8b\x17\x8d\x42\xfb\x72\xad\xbf\xce\xa8\xd4\xae\xb4\x59\x14\x42\xdb\xc4\x4e\x7f\x9d\x49\x23\x8e\xf7\x1c\x42\x4c\x88\xc3\xaa\x82\x17\xae\x35\x94\xfd\x87\x56\x85\x46\xeb\xe0\x8b\x61\x03\x90\x3e\xac\x93\x28\x22\xcb\xaa\xa2\xe4\xe1\xd1\xa7\x54\x96\x3c\x7c\x70\x7c\x7c\x70\xca\xaa\x6e\x01\xa6\x72\xac\x2a\xfe\x17\x4a\x19\x36\xed\x06\xc1\x93\x7e\x9d\x3a\xed\xac\x28\x47\x9c\x27\xea\xde\x80\x65\x15\x2e\x1a\x93\x06\x59\x54\xc9\xe8\xb5\x28\xe4\x7c\xdd\x9a\x97\x59\xb6\xc7\x82\x60\xb8\xe9\x14\xd8\xf1\x35\xd9\x7a\x6b\x24\x9a\x3d\x23\x93\xcb\x3d\x87\xca\x86\xfc\x52\xab\xac\x34\xdb\x0c\x3d\xa7\xcd\x53\xac\x43\x2b\xa8\xea\xec\x3b\xde\x13\x37\xd1\x4e\x2e\x19\x7b\xce\x93\xa5\x24\x9f\x53\x83\xfa\x42\x2c\xca\x8c\x17\x70\x07\x13\x69\x7a\x7a\xd7\x26\xd2\x8d\xda\x9d\x2a\x16\x3c\x97\xdf\x70\x5b\x47\xdc\x14\x91\xdc\xc1\x6c\xd8\xf5\xa3\x89\x3f\xd8\xe4\x6d\x0d\xa0\xa7\x45\x5c\x16\xd2\xac\x5f\x30\x6f\x1c\x84\xdd\xe1\x10\x31\x7b\xd3\x67\x7d\xf4\x91\xed\x19\xd9\xd6\x52\x38\x81\x47\xae\x3b\x85\x67\x93\x99\x0f\xc4\xef\x7e\x37\xec\x42\xd0\x3d\x77\x3f\xfa\x88\x05\x6e\xcf\x77\xc3\xe8\x91\x8b\x60\xf4\xa3\x1f\x7d\x7e\xde\x77\x9f\xf8\xee\x13\xff\x1f\xfe\xd6\x1d\x0c\x6d\xa5\x51\xad\x4c\xa1\x95\x14\x62\x29\xc8\x29\x27\x7c\xad\xd9\x70\x32\xf0\xc6\x91\xef\x8e\xdc\xd1\x43\xd7\x8f\xfa\xdd\x67\x68\x7e\x9f\xb2\xde\x64\xf2\xc8\x73\xa9\xa7\xd3\x10\x73\xc4\x6f\x04\x26\xdf\xf5\xe3\xcd\xbc\xe6\x18\xca\x08\x13\x89\x92\xaa\x86\x05\x6e\x6f\xe6\x37\x13\x62\x1f\xd1\x87\xc6\xc4\x59\xbd\x5a\x53\x45\x58\xe4\xa6\xae\x74\x58\x33\xde\x74\x9e\xa8\xdd\x84\x5f\x98\xef\x3e\x76\xfd\x00\x13\xec\xc9\xd3\x67\x54\x01\x76\xc7\xa1\xd7\xb3\xe9\x70\xa5\x80\x4f\x5b\x4f\xdc\x87\xf8\xa8\x85\x37\xb6\x91\xc3\x28\x4a\x0c\x62\xa5\xae\xa4\xb0\xf9\x59\x55\x81\x24\xfa\x96\x35\xda\x70\x53\xea\x6d\x02\x85\xac\x09\xc2\x6e\x38\x43\x97\x81\x3b\xd9\x6c\xe1\x96\x67\x35\x0f\x88\x54\x54\x91\xb2\x8d\x2d\x19\x8b\x17\x0c\x7d\xe2\x63\x37\xea\x4d\xfa\x6e\x34\xc4\xab\x91\x37\x9e\x59\x6f\x77\x78\xff\x80\xf9\x6e\xe0\x86\x91\x35\x9d\xf7\x0e\x3a\x83\x19\x71\xa3\x6e\x02\xa9\x7c\x2e\x8b\x25\x88\xd6\x92\xcb\xac\xc2\x2a\x0b\xa9\x8d\x2d\x3e\x32\xdf\x1d\x78\x41\xe8\xfa\x91\x3b\xea\x7a\xc3\x88\x1a\x8c\xfe\x68\xa7\x4f\x22\xac\x8f\xb4\x40\xcc\x4e\x46\x24\x93\x27\x40\x9a\x5e\xeb\x37\x8f\x63\x55\xe6\xb6\xa3\xd4\x54\x6f\x2f\x08\xdf\xc9\x2c\x69\x89\x94\x83\x6b\xb9\xa0\xaa\xab\x51\x40\x28\x9b\xe7\x6b\x93\xca\x7c\xd1\x66\x98\xfa\x7b\xbe\x1b\x05\xde\x60\xec\x8d\x23\xc4\xce\x0d\x0a\x23\xdc\x4d\xae\xaa\x1a\x67\x23\xbc\x8f\x27\xa1\x77\xfe\x2c\xc2\xdd\x34\x87\x23\xc8\x49\x84\xe1\x32\x7b\x40\x5d\x43\xfd\x60\x7f\x7f\x21\x4d\x5a\x5e\xb6\x63\xb5\x44\xdb\x96\x46\x93\x89\xef\x4b\xad\x4b\xa1\xf7\x0f\x4f\x4f\x36\xd9\xd8\x07\xb4\x6a\xf3\x92\xf7\x8d\x9d\xbc\x8f\x09\x95\xda\xc5\x7c\x65\xe2\x94\x63\xe6\x21\x13\xab\xde\xef\x48\xa9\xa2\xdd\xeb\x4e\xc3\xde\x45\x77\x1b\xfc\x6e\xc4\x65\xaa\xd4\x15\xba\xa2\x90\xb0\x77\x03\x53\xda\xf6\x64\xed\x84\x4a\x2d\xb6\x45\x3d\xdc\x26\xba\x54\x9d\xf1\xf8\x0a\x2f\x12\xa9\x63\x55\x24\xf6\x32\x5f\x18\x9e\x5d\xed\xb1\x1a\xe2\xe1\x68\x07\x68\xac\x03\xd5\x48\xbc\xb0\xe3\xd8\x19\x5c\x28\x75\x45\xa9\xfc\x07\xea\x3e\xd5\x4a\x11\xc9\xa8\xdb\xaa\x3d\xb7\x17\x78\xfa\x22\x93\xd7\xa2\xa0\x2a\x00\x66\x95\x68\x80\x22\x56\x79\xa2\x59\xdf\x45\xe5\xf7\xa3\xd0\x1b\xb9\x93\x19\x85\x9e\x93\xba\x02\x0c\x32\x27\xc7\x29\x1a\x65\x70\x64\x63\xf0\xc8\x9b\x46\xe1\x30\x88\x1e\xbb\xbe\x77\xfe\xac\x21\x8b\xf1\x06\x84\xa6\x52\x53\x8e\xd5\x28\x6a\x50\x2e\x84\xa8\x76\xc5\x17\x18\x12\x06\xde\x78\x10\x8d\x67\xa3\x2d\x0a\x95\x99\x28\xde\x05\x39\x67\xf0\xb0\x9c\xcf\xa9\x7c\x4c\x10\x00\xa1\x65\xca\xf3\x5c\x64\x0e\x5c\x09\xb1\x02\x49\xb1\x46\x12\x0c\xb1\x3d\x58\x48\x28\xa9\xbc\xca\xd5\x0d\xdc\x20\xf2\xa3\x87\x6d\x16\xb8\xe3\x7e\xf4\x70\x76\x7e\xee\xfa\xc8\x24\xcb\xa1\xaa\x02\x26\x5f\x21\x78\x59\x21\xaa\x23\x93\xa7\xda\x49\x79\xf9\x15\x46\x70\x04\xc2\x2c\x98\x3d\xfc\x6d\xb7\x17\x46\x53\xdf\x3d\xf7\x9e\x42\x07\x5e\x3e\xff\xf8\x4e\xdd\xcb\xbf\xab\x5f\xc0\xcb\xda\xa0\xaa\x0e\xda\x19\x0c\x96\x64\x29\x7a\x69\x56\xed\x05\x5e\xa3\x95\x3c\x38\xb9\xff\x29\x3b\x83\x2f\xbe\xa8\x1e\x7c\xfd\x35\xdd\xbd\x77\x8a\x8c\x1f\x2b\x23\x9c\x3a\x11\xa6\xae\x82\xc8\x93\x0a\x7d\xee\xdd\x3b\x3d\xd9\x73\x20\x18\x85\xd3\xaa\xbe\x72\x49\x4e\x35\x69\xc3\x8c\x7a\x55\xd4\x97\x0b\x87\x01\xa8\xdc\xce\x3d\xb9\xff\x29\x32\xa5\x10\x88\x3c\xed\xce\x30\x2f\xf0\xcf\x7b\x70\x7a\xef\xe0\xb3\x4d\x49\xe7\xad\xba\xef\x96\x90\x34\x55\x21\x27\xbb\xe1\x6b\xbd\x79\x5f\x05\x53\x1a\xa1\xfb\xc2\x1d\x4e\x40\xad\x84\xb5\x34\x0b\x05\x52\xa5\x0d\xc5\x16\x34\xa7\x44\xa2\x0c\x45\x6e\xda\xdb\x22\x1c\xce\x41\x22\x3d\x9b\x29\x6c\xc6\xa3\xc9\xed\x12\xdc\x81\x9a\xd4\xa5\xb1\xd5\xa2\x36\xc3\x71\xd4\xca\xb5\x41\x81\x5c\x2d\x39\x5a\x8b\x6d\x6c\x53\xb2\xd1\xc5\x51\xcd\x1d\xb7\x61\x92\x67\x6b\x82\x32\x26\x95\x36\x07\xd5\x22\x9b\xb7\xd0\x9f\x8a\xa4\x39\x51\x5b\xb5\xaf\x55\xde\x7a\x5f\x88\x33\x89\x49\x6c\x63\x1c\xe2\xb3\xa8\xe7\xfa\xa1\x77\x8e\xae\x6d\x1b\xc8\x6e\x69\xcc\x58\x8d\xff\x50\x67\xa6\x1a\xb1\x6d\xcd\x90\x7e\xd9\x06\x56\x92\x14\x42\x6b\x87\xa4\x79\x72\x7c\x74\x54\x15\x0d\x2b\xef\x44\x69\x07\xcf\x41\x50\xc0\xda\x0c\x56\x05\x6d\xff\xe5\xde\x98\x2f\xc5\x1e\xfc\x98\x1e\x7f\xde\x68\x92\xfd\xe4\x25\x58\x8b\x65\xe7\xfe\x64\x54\x55\x05\x70\x11\x5b\x78\x40\x41\x6b\xc5\xb5\xbe\x51\x45\x52\xe1\xd1\x26\x14\x45\xc6\x18\xf1\xca\xec\xaf\x32\x2e\x29\x1b\xb2\x14\xc9\x72\x55\x6e\x30\x3f\x40\x2e\x4d\x87\x5d\x6f\x1c\x85\xee\xd3\xb0\x01\xd5\x62\x1e\xa7\xbb\x70\x5b\x2c\x55\xb1\xb6\xd0\x35\x91\xe8\x70\x95\xbd\x4b\x23\xf7\x76\x3b\x1f\xd5\x60\xd6\xed\x77\xa7\x21\xc1\x14\x7b\xa7\x46\xb2\xd5\xf3\x0a\x1e\x0f\x7a\xb6\x78\x7c\xcd\xb3\x86\x4f\xdc\xa1\x78\x7a\xc0\xbc\x71\xe8\xfa\x8f\xbb\x18\x07\x4f\x0f\x6a\x42\x76\x2d\x16\x10\x37\xd6\xb2\xed\x71\x93\x36\xd7\x7c\x67\x67\x40\x13\x1e\x40\x6e\xcf\x2b\x74\x4c\xbc\x72\xf0\x61\xe7\xc1\xe9\xf1\xa7\x9f\x39\x35\x37\x3b\x4b\x1e\xf3\x42\xe5\x4e\x72\xd9\x39\x70\x56\x4a\x65\x94\xc5\x74\x0e\x0f\x0e\x1c\x99\x64\x22\xaa\x5c\x78\xc7\x62\x94\xfa\xcd\x0f\xe0\xe5\x36\x63\x38\x3c\x3c\x3a\x3c\x7c\x59\x9b\x28\xe2\x22\x3a\x67\x73\x3b\x4f\x31\x7d\xad\x58\x5a\xb3\xf7\x36\x7e\xd6\xc7\xa0\x9a\x0c\x9d\x16\xea\x5a\x22\x7e\x24\x70\xb4\x00\xb5\xb2\x98\xfc\xac\x1a\xf2\x80\xcc\xd0\x96\x15\xf3\x75\x3d\x6a\x2d\x0c\x26\xf5\x32\x13\x0f\xa0\x5a\xd9\xb6\xf5\x57\x95\x4c\x6c\xfd\xa5\x7a\xaa\x5f\xfe\x3f\xe3\x1e\x66\x5c\x0f\x60\xa1\x5a\xfa\xeb\xac\x95\x14\x18\x23\xf7\xe9\x26\x24\x3a\xaf\x17\xac\x4d\x21\xf3\x45\xbd\x32\x4c\xbb\x1e\xd4\xef\xfb\xbc\x5e\x63\x64\xd0\x09\xbe\xdc\xb0\x29\xaa\x4e\x98\x55\x29\x4f\xbd\x13\x2a\x2d\xd8\x2d\x57\xf0\x98\xd0\xf6\x2e\xaa\x95\x51\x26\xaf\x44\x64\xa1\x14\x3b\x43\x17\x8d\x11\x0d\x7d\x54\xcd\x2f\xcc\xc0\x11\x7c\x55\x6a\xdc\x74\x8d\xd6\xd5\xbc\x27\x19\xa8\xa0\xd2\x16\x9e\xef\xcc\x25\x30\x54\x41\x24\x44\xc8\x1b\x20\x5e\xd5\xcd\xea\xa5\x0f\x7a\x04\x24\x36\xa6\xb3\x43\xe4\xf8\xf4\xe0\x80\x0d\x7a\x51\x6d\x34\x04\x2c\xa0\x63\xef\x6f\x69\x64\x72\x6e\x9b\x12\x3b\x93\xef\x9f\xde\x3b\x38\x60\x81\x4b\x07\xbe\xa2\xa1\x77\xee\xd6\xd3\xed\x93\x33\xe8\x6d\xd9\x46\xce\xba\x17\xf8\xe7\x0c\xff\xbc\x95\x1a\x44\xb1\x2e\xe6\x8c\x3d\x5f\xc9\xd8\x94\x05\xf9\x93\xcd\xe9\x0b\x5b\xc2\xd5\x9b\xfa\x98\x48\x80\x5f\x73\xc3\x0b\xcd\xba\x8f\xbb\x61\xd7\x8f\x66\xd3\xe1\xa4\xdb\xdf\x29\xd3\xd6\x23\xce\xa0\x97\xca\x5c\x68\x51\x61\x42\xca\xf3\xed\xf1\x97\xbd\xa4\x54\x3a\x2d\xd5\x9e\x6d\x86\xf0\xba\x00\x66\xa7\x82\x56\x65\x11\x0b\x07\x50\xba\x16\x3c\x3f\xd8\xdf\x8f\xf3\xf6\xa2\xb0\x03\x08\x40\xdb\xcb\x7d\x36\xf0\xab\xa5\x04\x93\x99\xdf\xa3\x84\xaf\x1a\x46\x5d\x5b\xea\x0d\x65\xa5\xd8\xa0\x80\xb9\x2a\xe2\x4d\x89\x98\x0e\x46\xc8\x1c\xd4\x7c\x4e\x15\xbc\x25\x9d\x33\xab\xa3\x6e\x4d\xba\xa1\x17\xe7\x22\xa1\xd3\x16\x35\x23\x20\x53\xea\xaa\x5c\xe1\x16\x35\xf4\xc7\x41\x55\x6d\x89\x15\x82\x84\x6a\xc8\xb6\x37\xc0\xce\x2c\x3c\xa1\x50\x82\x10\x57\x88\x4d\x6e\x70\x73\x73\xd3\xce\xe4\x65\xbd\x45\x55\x2c\x7e\xc0\xfa\x69\x59\x6f\x6f\x00\x59\x3a\xa8\xe8\xa0\xae\x24\x52\x5f\xf2\x0c\xb1\x48\xa5\xb2\xe7\x6e\xdf\xf5\xbb\xa1\xdb\x8f\xde\xda\xdf\x07\xea\xcd\x36\x47\x61\xcf\xff\x3f\xa9\x32\xdf\x3a\xe8\x07\x95\x9d\xef\xed\x56\x9d\xef\xfd\x86\x45\xe7\x93\xb7\x5b\x00\xcf\xd1\xf6\x91\xd7\xc1\x4a\xc4\x72\x2e\x85\x3d\xe8\x51\xe1\x04\x64\xdb\xbc\xcc\xb2\x35\xa8\xd2\xac\x4a\x54\xcc\x04\x21\xd8\x2e\x51\xff\xbc\x77\x78\x78\x74\x5c\x13\xe1\x59\x8d\x5f\x45\x52\xf7\x9f\x50\x6a\xdd\x71\xe0\xf5\x1c\x98\xe5\xf2\x55\x9f\x23\xb8\xf6\xcb\xcb\x75\x75\x75\xde\xbb\x7f\x74\x54\x7f\x7e\x69\x2f\x4e\x0e\x9c\x9a\xf4\xe6\xc2\x3e\x3a\x3e\x3e\xfe\x6c\x73\x31\xe6\xb9\x72\xe0\x91\x34\x71\x2a\x72\x07\x02\xc3\x97\xab\xea\x63\x24\xb3\x4c\x6e\xae\xe3\x42\x11\x4c\xa0\xaf\x38\xab\x82\x10\x24\xca\x66\x7a\xc4\x2f\x31\x37\x6b\xb0\xa1\x36\x24\xcc\xb1\x55\xc6\xf3\x05\xda\xcf\xfe\xea\x6a\xb1\x8f\xdc\xdb\xff\xd1\xea\x6a\xd1\x8a\x55\xae\x0d\x47\x1d\x39\x9f\xf8\xa3\x6e\x68\x8b\xab\xf6\xf8\x54\xb6\x55\x76\x35\x07\x3a\x98\x52\x68\xf6\x3c\x53\x8b\x17\x6c\xf7\xbc\x4c\xaf\xca\x68\x91\x9a\xca\x44\x85\x6b\x2a\x6c\xd0\xc4\x03\xf5\x80\x1a\xfe\xaa\xe5\x92\xdb\x8a\x4f\x55\x31\x5f\x96\x99\x91\xab\xba\xb3\x58\x29\x67\x3d\xcd\x21\x35\xd9\x63\x55\x95\xb1\xba\xfb\x7f\x33\xc1\xbb\x25\xb7\xab\x31\x4f\x58\xf0\x98\x2a\xa0\x5e\x3e\x57\xf8\xf9\x84\x17\x39\x7e\xba\x45\xa1\x0a\xbc\x38\xe7\x86\x67\x6f\x6d\xd8\xce\x62\x43\xf7\xb1\x8b\x00\x90\xbe\xb2\x1a\x04\x6e\xd8\x65\x1d\x54\x9e\xad\x89\xbb\xed\xea\x3e\xea\x77\xd6\xe8\xc4\x51\x2d\x2c\x15\x85\x34\x35\xbd\x0d\x25\xe2\xcb\xdb\x64\xf0\xe6\x0f\xa0\x51\x39\x54\xeb\x9d\x74\xdd\x73\x17\x09\x4a\x1c\x0a\x65\x50\x2c\x77\xf4\x0d\x6a\x2a\x59\xaa\x42\xf7\x81\xe9\x62\x05\xd8\xee\xb2\xe1\x64\x10\xf9\x93\xd0\x66\x2b\x9b\x68\xbf\x20\x7f\x89\x44\x12\x2e\xb3\x35\xeb\x77\xbd\xe1\xb3\x77\xc6\x6d\x9c\x87\x4e\xe5\x9c\x20\x3e\xa6\xa2\x99\xed\xe2\xee\xf0\xf2\xe8\x7e\xd5\x8b\x3c\x84\x1f\xff\x18\x8e\xee\x3b\x70\x74\x72\xda\xf0\x2b\x51\x70\xe1\x9d\xd3\xc1\xde\xfb\x15\x5d\x72\xfe\x5b\x1f\xd3\x20\x4c\x93\x86\xde\xb8\xea\x61\xd1\x3f\x94\xf5\xab\x95\x2c\xc8\x5b\xac\x6b\x9d\xb7\xe0\xf2\x4e\x22\x32\x61\x04\xf0\xb9\x11\x05\x2c\xf9\x2b\x1a\x72\x97\xc8\x6c\x2a\xb1\x9b\x72\x37\xd5\x73\xde\x96\x06\xdd\xfd\x41\xe2\x78\x52\x15\x69\x66\xfe\x90\xd1\x91\x6e\x66\x29\x54\x45\x9f\xff\x43\x1a\xb6\xdc\x47\xc8\x27\x91\x7a\x95\xf1\xb5\x3d\x1f\x5d\x95\x84\x58\xa3\x80\xdc\x2c\x4b\x54\xef\x7e\xa5\x8a\x65\xa3\xbd\x47\x4c\x21\xdd\xa0\xea\xe5\x5b\x32\xf5\xad\xd2\xd8\xc6\x75\xc2\xd7\xd5\x80\x88\x34\xe0\x9d\x61\x2a\x8f\x2b\x82\xa4\x07\xe2\x55\x2c\x34\x02\x87\x57\xb0\x1b\x34\xac\x39\xd6\xed\x62\x12\x91\x51\xd6\xc0\xad\x6f\xb2\x41\xa4\x29\x93\x63\x4c\x08\x0b\xd5\x6c\x4c\x16\x65\x9e\xa3\xf2\xe2\xed\xea\xe0\xcb\x4a\x14\x52\x25\xf6\x90\xc9\x2d\x7d\x7c\xbf\xcc\x9b\xa3\xa9\x34\x41\xbd\x79\x5b\x3b\x6b\xd3\x4f\x24\xde\x39\xd5\x4c\x87\x16\x13\x72\x69\x74\xa2\x43\xdb\x95\xb4\xed\x0f\x0a\xa2\xea\xe6\x0b\x16\xf4\x2e\xdc\xfe\x8c\x72\xf6\xcf\x2d\xc3\x0e\x0f\x96\x8c\x2a\xef\x9b\x83\x06\xa9\xe0\x99\x49\xed\xb1\xdb\x8a\x4c\x21\x56\x2a\xb2\xf7\x23\xba\x7f\x1b\xa5\xa3\x7b\x29\xdb\x16\xe6\x4e\x0f\x10\x08\x74\x8b\x45\x69\x21\x09\x46\x49\x72\xc0\x79\x02\x9f\x2c\xa4\x81\xb9\x8e\xaf\x3e\xa9\x5d\x6e\xab\x55\xe6\x05\x46\x73\xe2\x5a\xab\x65\xf8\x42\xa3\xdb\xc6\xa0\x42\xa1\x47\xe5\x9b\xe0\x22\x4d\x4b\xc7\x4b\x02\xa0\x89\x8a\x35\xdd\x40\x62\xfb\x87\xed\x4f\xdb\x27\xac\xeb\x0f\x02\xeb\xab\x7a\x74\x70\xb8\x71\x84\x82\xce\x6e\x6a\x23\xe3\x9a\x3d\xb4\x97\x88\x76\x87\xcf\xf4\x8b\xb7\xb9\x4b\x42\xb9\x7d\xab\xf8\x82\x4c\xf0\xbc\x5c\x35\x5f\xc1\x8b\x38\x95\xd7\x42\x37\x19\x57\xdd\x8b\x62\x3b\xfc\x9d\x97\x58\x11\xde\xfe\x96\x33\x08\x31\x7b\xa9\xcf\x0d\x6f\xcf\x43\xcb\x79\xfd\xae\x46\xa3\xb8\x3a\xcf\xc1\x26\x43\x4c\xeb\xc2\x8b\x2e\x06\x16\x5a\xec\xf3\x85\x34\x8d\xe6\x95\x86\x54\x2e\xd2\x4c\x2e\x52\x72\x82\x3c\xa1\xbc\x22\x4f\xa0\x10\x4b\x75\x6d\x0f\x3d\xe6\x0b\xb1\x6d\x59\xf5\xbd\xf3\xf3\xe8\xc2\x1b\x5c\x0c\xbd\xc1\x45\xb8\x53\x93\x6f\x02\x2b\xf4\x81\x7a\x03\xf9\x90\x72\xd3\x0f\xa2\x03\x48\xe4\x7c\x4e\x55\x7f\xb2\x9c\x81\x17\x5a\xd2\x4d\xef\xf8\x0e\xd5\x38\xe5\x05\x8f\x0d\x66\x30\x44\x32\x6b\xf6\x62\x3f\x4c\x93\x0e\x6c\x76\x7b\xa1\x3d\xb3\x7f\x72\x0b\x71\x8b\x05\x75\xaa\x6e\xf2\x0f\xd0\xda\x9e\x40\x38\xf8\xb0\x5a\x2f\xe2\x86\x52\xf3\xc5\xa2\xc0\x1c\xf2\x1a\x75\x1a\x43\xdd\x6f\xa2\xd3\x8b\xb8\xd2\xe8\x41\x2f\xda\x2a\xf5\x64\x53\xb5\xbc\xa5\x3e\x8e\x52\x6e\x57\xf7\x5f\x30\x7b\xbc\xcf\x25\x63\x3c\xa8\x8e\x71\xda\xdf\x34\xb1\xde\x70\x32\x76\xab\xeb\xe9\x6c\x38\xac\x2e\x07\x3d\x5b\x36\x62\xcf\xad\xc7\x78\xd1\x38\x27\xdb\xac\x3d\xa5\xaa\x2c\x34\x5c\x0a\x73\x23\x44\x55\x26\xb7\xee\xa2\xef\x9e\x77\x67\xc3\x30\x6a\x54\xa1\xee\x33\xf6\x9c\xaf\xe4\x8b\x77\x18\x2f\x8d\x58\x6a\x9b\x53\xd9\x33\xfc\x36\x8d\xe2\xb6\xe2\x8e\xdc\xb7\xbf\x85\x0b\xdc\xc8\x0b\xdd\x91\x95\x1f\x63\xcf\x4b\xa2\xb5\x2d\xde\xef\x9c\xa1\xdc\x9c\xd9\x40\x81\x5a\xed\x50\x39\x9d\x99\xcf\x90\xe5\x44\xda\x7d\x3a\x1d\x4e\x7c\x37\xda\x29\xea\x1f\x1d\xec\x10\xb5\xb9\xd6\xfb\xc8\x11\x19\x2f\x08\x66\x6f\x11\x39\xdc\x25\xb2\x39\xd8\x5b\x9d\x99\xdc\x25\xc2\x63\x23\xaf\xa5\x59\xc3\x5c\x88\x84\x9d\xbb\x6e\x9f\x0e\x2b\xd9\xc3\x84\x15\xc1\x93\xcd\x21\x07\x35\x87\x3d\x93\x8a\xa5\x68\xc5\x2a\x53\xc5\x1e\x2c\x85\xe1\x60\xf8\xc2\xb1\x67\x34\x2f\xd7\xd0\xcd\x93\x42\xc9\x04\x7e\xd2\x81\x13\xfa\x89\x50\x17\x35\x9a\x5a\x4c\x40\x93\x28\x9b\x87\xbd\x5c\xe5\x55\x47\xbd\xee\xb4\x5b\x29\xd8\x5f\xf3\x34\x7e\x39\xa6\xcd\x3a\xdb\x34\xd2\x10\xfc\x6f\xdb\x68\x89\xb8\x16\x99\x5a\x89\x42\xb7\x17\x4a\x2d\x6c\x35\x76\xff\x46\x5c\xee\xdb\x90\xa3\xf7\x8f\x0e\x0e\xef\xed\x1f\x1e\xee\x07\x36\xcd\x69\xcd\x55\xd1\x6a\x6c\xa0\x25\xf3\x56\x2f\x2d\xd4\x52\xb4\x8e\x3f\xa3\x87\xd5\xf2\x59\x78\xe1\x8e\xdc\xa8\x37\x19\x4e\xfc\x68\xe4\x86\xdd\x28\xec\x0e\xa0\x03\x2f\x7f\x34\x9f\x9f\x1c\xdf\x3b\x7e\xd9\x84\x71\x32\x87\xcb\xb5\x11\x7a\x6b\xc8\x36\x29\xdf\x62\x8e\x3b\xcd\x8a\xcd\xe8\x61\x05\xa2\xbc\x60\x3a\xec\xda\xf2\x75\x1d\xf0\xef\x1f\xdf\xbf\x7f\x7a\x70\x9f\x14\xac\xbd\x69\xf6\x6f\x85\x59\x75\xd5\x3e\xa0\x10\x88\x69\x76\xf5\xe1\xe4\xe0\x5d\x4d\xfd\x20\x09\xdf\x9d\x4e\x3e\x48\x22\x57\x46\xc6\xbf\x46\x31\xc7\x93\xd0\xeb\xbd\xad\xde\x27\x3b\x64\x9a\xe7\x12\x3e\x48\x6b\xe2\x0f\xde\x59\x0f\x71\x08\xd9\x71\x8b\x1d\xfe\x86\xbb\x3b\xdc\x5d\x56\x2e\x6e\x34\x99\xc3\xaf\xd9\xa0\xfb\x24\x88\xc8\x60\x3e\x64\xc2\xb5\xd5\x7d\x88\x52\x7d\x72\x77\x87\xce\x31\x6e\x51\x1e\xde\xcf\x5f\xb0\x61\x77\x8c\x8e\x17\x44\xde\x9a\x05\xce\x37\x69\xab\x37\xc6\xbf\x17\x8f\xf0\x6f\xf8\xc4\x49\x44\xab\xef\x3a\xf3\xa2\x75\xee\x3b\x79\xd6\x1a\x0f\x9d\xec\xba\x35\x7c\xec\x14\x65\xcb\x9f\x39\x5f\xf1\xd6\x6f\x4f\x1d\xa1\x5b\x6e\xe0\xac\x4c\xeb\xa1\xef\xac\xb2\xd6\x74\xe8\x5c\x2e\x5a\x0f\x07\x8e\x34\x2d\x2f\x74\xe6\xb2\x75\xee\x39\xa6\x68\x85\xbe\x13\xeb\x56\xef\x4b\x47\x17\xad\x60\xea\xe8\xeb\x56\xe0\x3a\x57\xaa\xf5\xc8\x77\x16\x19\x52\x28\xaf\x5a\xb3\xae\x23\xf2\xd6\xe0\xa1\x93\x96\xad\x8b\x99\xa3\xaf\x5a\xc1\x23\x47\x26\x2d\xaf\xef\xcc\x79\xcb\xf3\x9d\x6b\xd9\x7a\x3c\xa6\x03\x38\xb8\x6a\x37\x5f\x64\x52\xa7\xce\xaf\xfe\xe3\xb7\x7f\xf3\x97\xff\xfc\x6f\x7e\xf6\x67\xbf\xfc\x83\xdf\x73\x7e\xf5\x17\xdf\xfd\xdd\xbf\xff\x17\xf6\xcb\xdf\xff\xe2\x1f\xff\xdd\xbf\xfb\x57\xbf\xfc\xd9\x7f\xfa\xfb\x5f\xfc\x93\xb7\x1f\xfc\xed\xef\xfd\xfc\x57\xdf\xfd\x1b\x7c\xd0\x17\xa5\xd1\x71\xea\xcc\x0b\x9e\x7f\xff\x27\x5c\x6a\x67\x2c\x12\x51\x64\x3c\x4f\xb4\x93\x71\x73\x2d\xc5\x5f\xff\x71\xe9\xbc\xf9\xf6\xcd\xef\xbe\xf9\xee\xcd\x77\xaf\x7f\xfe\xfa\x67\xaf\xff\xc2\xf9\xe5\x1f\xfe\xdb\x5f\xfe\xd1\x7f\xf8\xdb\x3f\xfd\xd7\x8e\xd0\x2b\xfe\xfd\x9f\xab\xcc\x41\x3f\x50\x2e\xca\xef\xff\x54\x43\xa2\xe0\x61\xc1\xb5\xc4\x9b\x99\xbe\x92\xce\xeb\x3f\x7f\xf3\x4f\x5f\xff\xb7\xd7\xff\xf9\xf5\x4f\xdf\x7c\x6b\x69\x38\xd2\xf0\x4c\xf2\x5c\x39\xba\x54\x4b\xe9\x84\xdf\xff\xa2\xb8\xfa\xfe\x4f\x84\xf3\x57\xbf\x2f\xfe\xfa\x8f\x8d\xcc\xb9\xf3\xe6\xbb\x37\xdf\xbe\xfe\xef\xd5\x70\x7d\x2d\x72\x7d\xc5\x9d\xff\xf5\x2f\xff\xe8\x7f\xfc\xd7\x3f\xfb\x9f\x7f\xf0\x5f\x9c\x05\xcf\xc4\x42\x39\x6f\x7e\xf7\xf5\xcf\xdf\x7c\xfb\xfa\xa7\x6f\xfe\xf0\xf5\x5f\xbe\xf9\xee\xcd\x3f\x7b\xfd\xf3\xd7\x3f\x75\x2a\xde\xc0\x9d\x59\x4e\x67\xea\x1e\xc9\x7c\x91\xa8\xe5\x5d\x67\xc4\x17\x6b\x5e\x38\x41\xa6\xae\x45\xfe\x57\xbf\x8f\xaf\xf1\xf2\x44\xe5\x42\x4b\x9e\x3b\x53\x51\xd0\xe7\x63\x29\xa8\xfb\x57\x61\x6f\x5d\xb5\xde\xd1\xf5\x61\xfc\x5d\xc9\xf8\x4a\x14\x56\x8b\xda\x78\x33\xe3\xf9\xe2\x05\x23\x35\x22\x75\x62\xa4\x4b\xd0\x81\x6f\x52\x46\x0a\x45\x97\xad\xf0\x09\xa3\xbf\x9b\x6f\xa4\x60\xf4\x6b\x68\x46\x5a\x86\xc8\xab\x60\xa4\x6a\xd0\x81\x3c\x63\xa4\x6f\xd0\x81\xec\x9a\x91\xd2\x41\x07\x8a\x92\x91\xe6\x41\x07\xbe\xe2\x8c\xd4\x0f\xdf\xa9\x19\xe9\x20\x74\x80\x3e\x19\xe9\x22\x7e\xcb\x18\x29\x24\x74\xe0\x72\xc1\x48\x2b\xa1\x03\xd2\x30\x52\x4d\x7c\xa1\x64\xa4\x9f\x84\x87\x19\x29\x29\x74\x80\x3e\x19\x29\x2b\x74\x40\x17\x8c\x34\x16\x2f\xaf\x19\xa9\x2d\x74\xe0\x4a\x31\xd2\x5d\xe8\xc0\x22\x63\xa4\xc0\xd0\x81\xf2\x8a\x91\x16\x5b\xbb\x1a\x3c\x64\xa4\xcd\xd0\x81\xb4\x64\xa4\xd2\x48\xe4\x8a\x91\x5e\xe3\x4a\x12\x46\xca\x4d\xa0\x93\x91\x86\x43\x07\xae\x25\xa3\x14\xba\x3e\xc5\xb8\xe4\xab\x15\xfd\x06\x50\x35\xa0\x6d\x9c\x71\x6a\x67\x11\x1e\x6b\x1b\xb5\xcc\x3a\x32\x97\xec\xf9\x66\x44\xbb\x9a\xf6\x82\xb1\xe7\xca\xa4\xe8\xd2\x82\x8b\xc9\x93\xe8\x7c\x32\x09\x5d\x3f\x7a\xe8\xdb\x9f\x3d\x35\xf0\x6e\x90\xaa\x9b\xcd\xcf\xcc\xde\x2d\x88\x51\xaa\x86\x60\x70\xa0\xea\x73\xf6\x73\xa5\x8c\x28\x76\xe8\x6e\x7f\x73\x56\xd7\x2f\x90\x2a\xf5\x29\x9a\xbf\x37\xb3\x3f\x1b\xab\x7a\x28\xef\x21\x15\xba\xa3\xe9\x10\xd3\x5d\x6a\x02\x54\x0d\x08\xa2\xfa\xbf\x03\x00\x00\xff\xff\xe9\x0d\x1d\x76\x90\x40\x00\x00")
+var _confAppIni = []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xe4\x7b\xdd\x8f\xe3\xc8\x76\xdf\x7b\xfd\x15\xb5\x7d\xb3\xd9\x19\x83\x52\x7f\x4d\xf7\xf6\x4e\x5f\x5d\x2c\x47\xa2\xd4\xf4\xe8\x6b\x49\x6a\x3e\xb6\xd1\xe0\x54\x93\x25\xb1\x56\x14\x8b\xcb\x2a\x76\x8f\x16\x81\xb1\x0b\x3f\x38\x09\xe2\xa7\x24\x36\x02\x18\x01\x8c\x20\x31\xe0\xc4\xc9\x35\x92\x00\xd7\x37\xd7\xc8\xc3\xda\xef\x33\xff\x83\x71\xaf\x1d\x24\xf0\xbf\x10\x9c\x53\xa4\x44\xf5\xf4\xcc\xdd\x1b\x24\x4f\x99\x01\x5a\x14\x59\x75\x58\x75\x3e\x7f\xe7\x9c\xd2\x8f\xe8\x47\x1f\x7d\x44\xc7\xce\x33\xc7\xa3\xf8\x67\x34\xe9\xb9\xfd\x97\x34\xb8\x70\x7d\xda\x77\x87\x0e\x3c\x27\x66\xd4\x74\xe8\xd8\xbe\x43\x47\xf6\x53\x87\x76\x2f\xec\xf1\xc0\xf1\xe9\x64\x4c\xbb\x13\xcf\x73\xfc\xe9\x64\xdc\x73\xc7\x03\xda\x9d\xf9\xc1\x64\x44\xbb\x93\x71\xdf\x1d\xdc\xa5\xe0\xf6\xe9\xcb\xc9\x8c\xda\x9e\x43\xa7\x76\xf7\xa9\x3d\x80\x19\x53\x6f\xf2\xcc\xed\x39\x9e\xb5\xf3\x82\xc9\x73\xa0\x3c\x7d\x49\x27\x7d\xea\x06\x48\x83\x9c\x53\x3b\xcf\x69\xc6\x56\x9c\xea\x84\x69\xaa\x12\x79\xab\xa8\xcc\x28\xbf\xe1\xc5\x9a\xe6\x6c\xc1\xa9\x16\x3a\xe5\xc4\x9e\x4e\xc3\xb1\x3d\x72\x68\x87\x0e\xe4\x42\x91\x73\x1a\x24\xdc\xcc\x94\x73\xaa\x13\x4e\xd5\x5a\x69\xbe\xa2\xa5\xe2\x85\x21\x56\x94\x99\x32\x83\xbd\xd9\x38\x9c\xf9\x8e\x47\x3b\x74\x21\x34\x39\xa7\x8e\xd0\x09\x2f\xe8\x5e\xcc\x6f\xf6\x2c\xba\x97\x17\x32\xde\xa3\xb2\xa0\x7b\x9a\x2b\xbd\x87\xe3\x47\x93\x1e\xbc\x2c\xe6\x37\x84\x5c\x2a\x5e\xdc\xf0\xe2\x8a\x4c\xbd\x49\x30\xe9\x4e\x86\xb4\x43\x13\xad\x73\xd2\x9b\x8c\x6c\x77\x4c\x3b\x34\x95\x11\x4b\x13\xa9\x34\xf1\x26\x93\x20\x9c\x79\x30\xe4\xe3\x07\xf5\xf8\x87\xea\xf1\xfe\xfe\xc7\x0f\xcc\xf0\x87\xea\xf1\xc7\x0f\x2e\x82\x60\x1a\x4e\x27\x5e\xf0\x50\xed\x13\xfc\x62\xf7\x7a\xb0\xc0\x83\x36\xfe\x27\x9b\x01\xb4\x43\x8f\x0f\x0e\x0e\xc8\x39\x9d\xf2\x62\x25\x94\x12\x32\xa3\x73\x59\xd0\x32\x13\xaf\xa9\x92\xd1\x92\x6b\x32\x1b\xbb\x2f\x42\x7f\xd2\x7d\xea\x04\xe1\xd4\xf1\x46\xae\xef\xbb\x13\x58\xd8\xe9\xe9\x29\x39\xa7\x43\x58\x1e\x7d\xd0\x1b\x7d\xf9\x90\xc2\xda\x60\x3a\x70\x86\xde\xca\x62\xc9\x0b\x45\x1f\xa8\x32\x4a\x28\x53\xd4\xf7\x2f\x68\x99\xc7\x4c\xf3\x87\x94\x45\x11\x57\x4a\x64\x0b\x7a\xcb\xaf\x29\xf0\x40\x44\xbc\x4d\xce\xa9\x9b\xd1\x95\x54\x9a\x46\x4c\x71\x45\xd7\xb2\xa4\xb1\xa4\x99\xd4\x34\xe3\x3c\xa6\x5a\xd2\x28\x61\x19\x88\x2e\xe1\x34\xe6\x73\x56\xa6\x9a\xde\xb0\xb4\xc4\xc9\x76\xaa\x79\x41\x85\xa6\x32\x4b\xd7\x54\xcc\x61\x7e\x81\xef\x35\x5c\xa6\x99\x8c\x39\x15\x0a\x09\xa2\x60\x41\xc8\x4c\x51\xe0\x08\x3e\x6c\x93\xe1\xa4\x6b\x0f\xc3\x0f\xb1\x7a\xc3\xd2\x77\xb9\x7d\x4e\x7b\x42\xb1\xeb\x94\xe3\x4b\xe7\x9c\xe9\xb2\xe0\xf4\x36\xe1\x19\xbe\x92\xdd\x30\x91\xc2\x63\xd2\x73\x7d\xfb\xc9\xd0\x09\x61\x58\x87\xce\x59\xaa\x38\x39\xa7\xcf\x13\x8e\xca\x53\x2a\x4e\xaf\x4b\x91\x6a\x91\x35\x57\x2f\x61\x03\xba\x4d\xfc\xc0\xf6\x02\x98\x1a\xfa\x8e\xf7\x0c\x75\xaf\xa6\xd0\x93\x2b\x26\xb2\x4a\xed\x25\xbd\xe6\x94\xbf\xce\xa5\xe2\x31\xad\x48\x45\xa9\xcc\x38\x08\x8a\xc0\xfc\x8d\x92\x6d\x15\x08\x94\x41\x16\x9a\x66\xe5\xea\x1a\xd4\xfd\xd7\x13\xa9\x34\xe9\xe8\x88\x9c\xd3\x31\xd7\x20\x77\x2a\x32\xcd\x8b\x39\x8b\xee\xdd\x47\x2a\x94\xe6\x19\x18\x23\xce\x1f\xba\x7e\xe0\x8c\xc3\x8b\x89\x1f\x34\x94\x74\x77\x19\x3f\x98\x4a\xb5\x98\x8f\x1f\xd4\x2b\xc3\x1d\x79\x52\x6a\x9a\x33\x9d\x80\x45\x03\x8d\x58\x14\x3c\xd2\xb2\x58\x5b\x1b\x2d\x12\x8a\x7e\xf2\x3b\xfb\x6d\xa5\x92\x4f\x2c\x7a\x5d\x6a\x54\xbe\x84\xdd\x20\x23\x41\x22\x9f\xec\x27\x72\xc5\xf7\x17\x42\x9b\x51\x6d\x7c\x2f\x6a\xca\xd4\x0e\x2e\x68\x07\xd5\x37\x16\x11\xd3\x28\x73\x14\xa5\x96\xb4\xe0\xb7\x85\xd0\x9c\xb2\x52\x27\xb2\x10\xdf\xf0\x38\x5c\xf2\xb5\xa2\xe0\x94\x34\x2b\xb4\x45\xc5\x22\x93\x05\x8f\x8d\xa2\xdc\x2f\x7c\xe2\x39\xcf\x3d\x37\x70\x42\x7b\x16\x5c\x4c\x3c\xf7\x4b\xa7\x17\x3e\x75\x5e\xfa\xa1\x1d\x84\xa8\x0f\x0d\x25\xe8\x26\x52\x2a\x63\x22\x91\xc8\x13\x30\x42\x2d\xa9\x2a\xf3\x1c\x38\x0a\x06\x8a\x42\x94\x59\xc6\x23\x2d\x64\xa6\xc8\x56\x97\xc2\xae\x3b\xbd\x70\x3c\x9f\x76\x28\xe3\xea\xf0\xe8\xac\x15\xe9\xc2\xc2\xeb\xcf\x8e\x36\xd7\x47\x27\xa7\xdb\xfb\x47\x67\xad\x45\xb4\xfa\x5c\xe6\x3c\x53\x2a\x69\x47\x72\x65\x51\x56\x44\x73\x59\x16\x47\x27\xa7\x9b\xeb\xc3\xa3\x33\xb4\x8f\x8a\xf1\x68\xcb\x05\x07\x5e\x69\xbe\xca\x65\xc1\x8a\x35\x9d\x8b\x94\x2b\xc3\x06\x70\x97\x34\x2f\xaf\x53\x11\x2d\xe9\x92\xaf\x69\x89\xee\x42\xa9\xa4\xb5\xe4\xeb\x05\xcf\x2c\x72\xde\x94\x5d\xe5\xa3\xb7\xb4\x36\x22\x36\x72\x7a\xea\xbc\x0c\x03\xc7\x6f\xc8\x6a\x0a\xfa\x00\x8c\xd9\x92\xdc\x51\x86\xed\xfd\x4f\x28\xcb\x62\x9a\x72\x88\x22\x3c\x4d\xe9\x5c\x64\x31\x95\xa5\xa6\xb7\x89\x88\x12\x0a\xc6\x00\xbb\x61\x69\xba\x79\xd7\x00\x74\x11\xdf\xd4\xa0\xff\x1e\x05\x89\x12\x1e\x2d\xe9\x4a\x64\x62\x55\xae\x70\xaf\x4a\x7c\xc3\xe9\xad\xd0\x09\x8d\x64\x51\x70\x95\xcb\x2c\x86\xdd\xeb\x75\xce\xc9\xc8\x1d\xbb\xa3\xd9\x08\x77\xe4\xbb\x5f\x3a\x61\xf7\xc2\xe9\x3e\x6d\x3a\x81\xca\x07\x75\x7b\x63\x88\x76\x19\x98\x6d\x15\x88\x56\x32\xe6\x64\xd2\xef\x0f\xdd\xb1\x53\xc7\x21\x33\xad\xf6\x48\xde\x64\x16\x38\x5e\x38\x9c\x0c\x1a\x14\x07\x3c\xe3\x05\xac\x5a\x69\x9e\xab\xc7\xe4\x9c\xfe\x03\xda\xde\x5f\x80\x9b\x8f\x78\xa1\x69\x2b\x62\x1d\x5d\x94\x9c\xb6\xe2\xb2\x60\xa0\x53\x9d\xb3\x4f\x4f\x0f\x92\x83\xd5\x81\xa2\x2d\x08\x5e\x9d\xd5\x1a\x3e\xda\xfc\x35\x5b\xe5\x29\x07\x2d\x21\xe7\xe4\x9c\x4e\x0a\x3a\x2f\xe4\x8a\x32\xda\xce\xe7\xaf\x51\x01\xd0\xdb\x14\x9a\xc7\xe6\x09\xa8\xf1\x73\x91\xc5\x10\xbe\xe1\x65\x62\x6e\x18\xa8\xb4\x2c\x38\x7d\x10\x4b\x72\x8e\xce\x75\x2e\x8b\x05\xd7\xc0\x4f\x33\x1f\x27\xe6\x85\xb8\x81\xc1\x4b\xbe\x7e\x68\x96\x6d\xd4\x34\xa5\xf9\x32\x52\x87\x47\xb4\x25\x32\xa4\x8a\x6f\x6f\x81\x4c\xcd\x37\xbe\xa2\xad\x4c\x82\x9d\xfe\xb0\x59\x4b\xbe\xae\x27\xc1\x03\x05\x17\x31\x57\xa4\xeb\x78\x41\x88\xc8\xa6\x43\xa3\x52\x69\xb9\xda\x87\xf0\xae\xf6\xeb\xd7\x10\x10\xe3\x7d\x03\x2a\x8a\x18\xd6\x52\x79\xcb\x63\x1a\x0c\x7d\x7a\xc3\x0b\x8c\xd2\x18\xf3\xd4\x63\xea\xfb\xc3\xe3\x03\x0b\x1e\x1d\x56\x1f\x87\xe6\xe3\x88\x04\x43\x3f\x1c\xb9\xe3\xf0\x99\xe3\x55\x11\x1b\x47\x01\x34\x9a\xe5\x39\x78\x50\x7e\xc3\x53\xc4\x38\x7c\x95\xa7\xc0\x26\x50\x73\xa5\x99\x16\x91\x91\x04\xb8\xcc\x5d\x33\x43\xa6\x82\xe1\xdc\x26\xbc\xe0\x26\xd2\x0b\x45\xf9\x6b\x1e\x95\x9a\xc7\x10\x9b\x02\xb7\x7b\xc7\x2b\xf6\xaa\xf9\x38\x11\xfc\x0f\x40\xb3\x98\x69\x86\xd8\xab\x67\x07\x76\x6d\x2b\x78\x13\xa1\x5b\x0a\x52\x86\x9d\x9a\x55\x0e\xbe\x74\xa7\xb5\x0b\x23\xce\x18\x55\x15\xef\x6d\x95\x74\xc8\x8c\x91\x20\xb4\x9b\x63\xb0\xcc\x5a\xa9\x5c\x2c\x78\x8c\xd0\x4d\x59\x34\x62\x19\x84\xb3\x3d\x70\xe4\x06\x95\xf1\xd7\x79\x2a\x0b\xbe\x47\x86\x36\x62\xd2\x70\x6a\x0f\x40\x14\x30\x82\x90\xcb\x82\xe7\x52\x09\xf0\x22\x57\x3b\x61\x04\xc8\x83\x02\xc2\xfb\x36\x63\x04\x57\x9f\x28\xdc\xc2\x8e\x23\xd9\xfb\x9d\xfd\x1f\xc3\xfb\x21\x28\xff\x04\x8d\xa6\xd5\x9c\xb2\x87\xb8\x0e\xf9\x04\xb8\x53\x45\x85\xc8\x35\x5a\x7a\x1d\xe9\xaa\x6d\x2b\x8b\x2a\xb9\xe2\x5a\xac\xb8\xa2\x91\x2c\xd3\x18\xf7\xa2\x92\x3d\xe2\x77\x3d\x77\x1a\x84\xc1\xcb\x29\xac\xfd\x9a\xa9\xa4\xc1\x75\x7b\xec\xbb\x00\x9b\x0a\xc5\x8d\xf7\x67\x19\x2d\xb3\x82\x47\x72\x91\x41\x34\xaa\x9f\x11\x18\x18\x76\x2f\x6c\xcf\x77\xcc\x7a\xfa\xb2\x88\x78\x05\x98\x33\x7e\xbb\xdd\xe9\xba\xc2\x05\x95\x79\x91\xfe\xc4\xeb\x3a\xe1\xd4\x73\x9f\xd9\x81\xd3\xf4\x1b\xa9\xbc\x66\x29\x5d\xb1\xd7\xe8\xda\xd0\xdf\xa3\x4c\xc5\x0a\x50\xda\xbc\x49\x31\x37\xc0\xa7\xb0\x68\xeb\x90\xae\x38\xcb\x00\xa6\x99\x91\x64\x64\xbf\x08\xbb\x9e\x63\x07\xee\x64\x1c\x0e\xdd\x91\x0b\xe1\xae\x75\x48\xce\xe9\x48\x14\x05\xc8\x62\x9d\x45\xf4\xeb\x92\x97\x9c\xa6\x3c\x5b\xe8\xc4\xa2\x22\x83\xd7\x29\x0e\x38\x70\xb5\x1d\x85\x41\x04\xc2\xae\xa2\x80\x24\x45\xb6\x20\x23\xd7\xf3\x26\x5e\xf8\xc5\xcc\x99\x39\xe1\xd0\x19\x0f\x50\x15\x0f\x2b\x64\xcc\x74\x94\x98\x68\xf4\x7e\xfa\x79\x99\xa6\xb4\xe0\x5f\x97\x18\xb4\x36\x33\xee\x79\xd7\x74\x36\x1c\x86\x9e\xf3\xc5\x0c\x42\xd1\x7b\xde\x58\xf0\x39\x2f\x00\x0f\x0c\x45\xc4\x33\xc0\xc1\x5a\xd2\x3c\x05\x34\xc5\x8c\x5b\xd3\x32\xaf\x73\x13\x80\x41\x00\xbc\x00\xf1\xad\x4a\xa5\xe9\x0a\x5f\x8f\xe6\x8b\x30\x10\x5c\x95\xcc\xe6\xfb\xa9\x21\x06\x5a\x5f\xf9\x99\xe6\x6d\x32\xf5\x9c\xbe\xe3\x79\x4e\x2f\x1c\xba\x5d\x67\xec\x3b\x00\x01\xec\x9c\x45\x09\xaf\xd7\x41\x8f\xda\x07\x16\xf0\xbe\xfa\xde\x08\x35\xec\x5a\xa4\x42\xa3\x5a\x20\xf4\x63\x91\x36\xf1\xab\xa9\xe9\xf4\x7a\x6d\x90\x76\x5e\x48\x2d\x23\x99\x6e\x82\x0e\x82\xe8\x81\xdb\x04\x31\x4e\x76\x97\xf0\x4a\x2c\x30\x06\x35\x74\xe6\x7a\x6d\xd2\x23\xe3\xa8\x2a\xb7\x60\x10\x3c\x38\x94\x70\xe4\x0e\x3c\x54\x9a\x26\x3a\x92\x59\x54\x16\x05\xcf\xa2\x35\x58\x67\xa9\x4c\x5e\x51\x70\x5d\x08\x7e\xc3\x69\x24\x57\x2b\xa1\x15\x15\xd9\x5c\x16\x2b\xd4\xd7\x36\x0d\x12\xa1\xe8\x0d\x2b\x04\x2e\x2a\xe6\x73\x91\x01\x2d\x10\x40\xad\xdc\x15\x52\x05\xb1\x30\xb5\x54\x26\x51\xac\x1c\x4e\x51\x66\xb5\xe8\x30\xe5\x00\x1b\x6e\xd3\x99\x2a\x59\x9a\xae\x2d\xb8\x4f\xce\x8d\x4b\xa7\x31\xcf\x39\xa0\x8b\x39\x4d\xe4\x2d\x5d\xb1\x6c\x4d\xbb\xd3\x99\xa2\x0f\x22\x59\x70\xf5\x70\x83\x4a\xdb\xd4\x35\x0a\x60\xa6\x01\x02\x32\xd1\xef\x1b\x5e\x40\x48\xc4\x2c\x2e\x06\x73\x1a\x4c\x06\x3e\xbd\x15\x69\x0a\x08\x54\xc2\x8e\x00\xa9\xac\x69\xcc\x35\x8f\xcc\xa2\xb6\x6b\xc7\x77\x61\xda\x54\x01\x2a\x78\x17\xe9\x4e\x46\x23\x37\xf0\xc3\xbe\x13\x74\x2f\xc2\xee\x64\xdc\x9d\x79\x9e\x33\xee\xbe\x04\xc0\xbe\x15\x56\xc1\xe1\x8d\x08\x32\xd0\xd1\x14\xec\x16\x15\xb1\x96\x8c\x67\x3f\xc7\x50\x17\x7a\xce\xb8\xe7\x78\xbb\x00\xa4\xe9\x6c\xdb\x3c\x86\x4f\xf0\xb9\x43\xa1\xd0\x53\x54\xc8\x00\x20\x3f\x40\xd6\x4d\x52\x0f\x6e\x10\x51\x7a\x2a\x32\x4e\x6f\x0b\x96\x83\xe8\x70\x57\x5d\x19\xf3\xca\x3f\x18\x7a\x90\x23\xfa\x3c\x67\xa8\x46\x0d\x5a\xa8\xa9\x0c\x25\xcf\xda\x34\x90\x5b\x5a\x35\x22\x15\x3a\x81\x28\xbf\x99\x63\xd1\xaf\x4a\xc4\xa7\xba\x9e\x47\x10\x52\x3d\xf7\xec\x69\xe8\xbc\x08\x9c\x31\x84\x5c\x30\xa1\xb6\x7e\xad\xad\xf6\x2a\xb6\xda\x2b\x56\x2c\x63\x79\x9b\xc1\x37\xf3\xb1\x8c\x01\xc4\x3e\x63\xa9\x88\xcd\xfe\x80\x73\xd5\xd6\x70\x4f\x8c\xe6\x05\xbf\x11\xfc\x96\xda\x53\x97\x32\xa5\x64\x24\x18\x20\x23\x5c\xb1\x4e\xf8\xca\xa2\x75\x7a\xcd\x72\xb1\x7f\x73\xb8\x5f\xbf\x65\x67\xaf\x06\x2d\x80\xb9\xe0\x5a\x55\x1b\x9c\x0c\xd2\xd5\xec\x1a\xd8\x05\xfc\x31\x72\xbb\x95\xd9\x27\xa6\x5a\x02\x8e\x0d\xd8\xb8\xcb\x79\x1a\x4b\xae\x60\x08\xfa\x19\x70\x1b\xcf\x5c\xe7\x39\x8a\x17\x45\x0b\x32\x85\x7d\xd7\xeb\xd8\x95\x6b\x99\xa7\x92\xc5\x57\x4d\x95\xd9\x18\x33\xbe\xc7\x0c\x50\xed\x4a\x65\x7a\xb4\x43\x01\x58\x36\xe0\x7a\x8d\xf0\x45\xba\xae\x30\x60\x35\x87\x3e\x88\x9b\x38\x63\xc1\xb5\xa2\x51\xca\x59\xc6\x63\xd8\xb9\x81\x2a\x75\xfd\x07\xdd\xf2\x43\x12\x38\xa3\x69\x13\x7b\xec\xeb\x55\xbe\x5f\xd1\x83\x00\x08\x4b\x82\x50\x5c\x09\x85\x15\x9c\xb2\x0a\x8d\x99\x08\x68\xc6\xf2\xd8\xa2\xbc\xbd\x68\x53\xb1\x62\x0b\xbe\xff\x55\xce\x17\xff\xc8\x5c\xe6\xd9\xa2\x4d\x87\x1c\x84\xc9\x57\xb9\x5e\x57\x91\x0d\x89\x50\x30\xee\x79\xfd\x0a\x62\x0f\x87\x93\xe7\x4e\x0f\xa3\xb8\x8f\xf1\x77\x54\xb9\x16\x4c\x07\xe4\x9c\x72\x56\x7b\x76\x91\xd1\xd1\x13\x62\x18\x6e\xbf\xc0\x34\x80\x76\xe8\x71\x63\xce\xd6\xa4\x8d\x0a\x63\x78\xc5\xc5\x62\x34\x85\xa9\x20\xa6\x13\xac\x94\x69\xcd\xa2\x64\xc5\x33\x0d\x4e\x04\xc2\x96\x32\xf6\xcb\x53\x88\x70\x0a\x44\x88\x57\x6d\xb6\x19\x79\xd5\xa8\x57\x6c\xef\x2a\x64\x11\x47\xd9\xc6\xed\x1a\x82\x60\x00\x7b\x05\x72\x7c\xf5\x1e\xb9\x22\x2c\xd9\x52\xb9\x33\x13\x25\xd3\x78\xfc\x8a\x34\x45\xd6\x78\x00\x09\x45\x86\x21\x6e\x25\x9b\xa2\x02\x09\x7e\x40\x42\x77\x59\x4f\x7f\x6b\xff\xb7\x0c\x2b\xdf\x65\xfd\xee\xd2\x8e\x8f\x46\x4f\x48\x53\x02\x47\xd5\xbc\xf7\xb3\x7f\x97\xc0\xe1\xc1\x8e\x38\x00\x9e\x5f\xd6\xa6\xd3\x30\x93\x84\x15\xb1\xf1\x4a\xd7\x05\x67\xcb\xad\x39\xd6\xae\xf5\xc2\xf6\x20\x72\x8f\x9d\xf0\x89\xe7\xd8\xcd\x6c\xb0\x76\xa0\x26\xe8\xd3\x99\x37\x6c\xf9\x51\xc2\x57\xf7\xe9\x34\x53\xf0\x92\x65\x95\x82\x1b\x77\x0e\x20\x66\x54\x1b\xf3\x39\x4a\xaa\x4a\xe2\xe8\x42\x68\x6b\xc5\x16\x19\xd7\xc4\x94\x72\xc3\x99\x37\x0c\xfd\xee\x85\x33\xaa\x34\xf8\x87\x78\xef\xeb\x3a\x70\xf0\x78\x1f\xfc\x90\x59\x47\xe3\x95\x3f\xc8\x65\x57\xb1\xa7\xf2\xd7\xfb\xb2\xe1\xb1\x98\xda\x78\xa3\x7b\xfc\x36\x1a\xd1\xae\xcb\x7e\x9f\xb7\x26\xe4\x52\xad\x58\xa1\xd7\x39\xcb\xb4\xba\x6a\xe8\xb2\x61\x76\xdf\xb3\xbb\x41\x45\x04\xb5\xbb\x67\xfb\x17\xce\xe6\xdb\xd0\x0e\x9c\x17\xe1\xee\x3d\x7b\x3c\x18\x3a\xbd\xf0\x8b\xd9\x24\xd8\xde\x24\x97\x90\x02\x5e\x99\xd8\x50\x9a\x58\x6a\x63\xc5\xb4\xd5\x95\x99\x2e\x64\xda\xc2\x9c\xb0\x35\x29\xc4\x42\x64\x34\xe1\x0c\x23\x7d\x23\xe9\xc0\x0a\xa7\x84\xf0\xa1\x78\xa6\x89\xdd\xed\x3a\xbe\x0f\x91\x3b\xf0\x26\xc3\x10\xf5\x3d\x9c\x78\xee\xc0\x1d\xd3\x0e\x31\xc9\x02\x68\xd7\x46\x11\xd2\x85\x2c\x84\x4e\x56\x0a\x73\x42\x9d\x70\x51\xec\x54\x28\x0c\x0a\xa6\x0f\x4a\xc5\x01\xaf\x6b\x49\xe3\x1a\x0a\xa2\xb9\x3d\x24\x97\x4a\x25\xed\x6a\x4a\xb8\xe4\xeb\x10\x4c\x09\x98\xd6\x3b\x3a\x39\x39\xfc\x8c\x76\xe8\xd1\xc9\x29\x71\xba\x3d\xdf\xa6\xb4\xfa\xe6\xe1\x35\x7e\x3b\x78\x74\x46\x7a\x9b\xaf\x87\x07\x47\x8f\x08\xb9\x04\x7b\xbf\x66\x8a\x5f\x35\x0a\xed\xab\xb5\xfa\x3a\xc5\x52\xbb\x54\x7a\x51\x70\x65\x12\x3b\xf5\x75\x2a\x34\x3f\xde\xb3\x10\x31\x01\x0e\xab\x0a\x5e\xb0\xd6\x40\xf4\x9e\x18\x15\x1a\xad\xfd\x2f\x86\x0d\x40\xfa\xa4\x4e\xa2\x90\x2c\xa9\x8a\x92\x87\x47\x9f\x62\x59\xf2\xf0\xf1\xf1\xf1\xc1\x29\xa9\xba\x05\x90\xca\x91\xaa\xf8\x5f\x48\xa9\xc9\xd4\xf6\xfd\xe7\xbd\x3a\x75\xda\x59\x51\x06\x38\x8f\xd7\xbd\x01\xc3\x2a\x58\x34\x24\x0d\xa2\xa8\x92\xd1\x1b\x5e\x88\xf9\xba\x35\x2f\xd3\x74\x8f\xf8\xfe\x70\xd3\x29\x30\xe3\x6b\xb2\xf5\xd6\x50\x34\x7b\x5a\xc4\xd7\x7b\x16\x96\x0d\xd9\xb5\x92\x69\xa9\xb7\x19\x7a\x86\x9b\xc7\x58\x07\x56\x50\xd5\xd9\x77\xbc\x27\x6c\xa2\x1d\x5f\x13\x72\xc9\xe2\x95\x40\x9f\x53\x83\xfa\x82\x2f\xca\x94\x15\xf4\x01\x24\xd2\xf8\xf4\xa1\x49\xa4\x1b\xb5\x3b\x59\x2c\x58\x26\xbe\x61\xa6\x8e\xb8\x29\x22\x39\x83\xd9\xd0\xf6\xc2\x89\x37\xd8\xe4\x6d\x0d\xa0\xa7\x78\x54\x16\x42\xaf\xaf\x88\x3b\xf6\x03\x7b\x38\x04\xcc\xde\xf4\x59\x1f\x7d\x64\x7a\x46\xa6\xb5\x14\x4c\xe8\x53\xc7\x99\xd2\x97\x93\x99\x47\x91\xdf\x3d\x3b\xb0\xa9\x6f\xf7\x9d\x8f\x3e\x22\xbe\xd3\xf5\x9c\x20\x7c\xea\x00\x18\xfd\xe8\x47\x9f\xf7\x7b\xce\x73\xcf\x79\xee\xfd\xc3\xdf\x7a\x00\xa1\xad\xd4\xb2\x95\x4a\xb0\x92\x82\xaf\x38\x3a\xe5\x98\xad\x15\x19\x4e\x06\xee\x38\xf4\x9c\x91\x33\x7a\xe2\x78\x61\xcf\x7e\x09\xe6\xf7\x29\xe9\x4e\x26\x4f\x5d\x07\x7b\x3a\x0d\x31\x87\xec\x96\x43\xf2\x5d\x3f\xde\xcc\x6b\x8e\xc1\x8c\x30\x16\x20\xa9\x6a\x98\xef\x74\x67\x5e\x33\x21\xf6\x00\x7d\x28\x48\x9c\xe5\xeb\x35\x56\x84\x79\xa6\xeb\x4a\x87\x31\xe3\x4d\xe7\x09\xdb\x4d\xf0\x85\x78\xce\x33\xc7\xf3\x21\xc1\x9e\xbc\x78\x89\x15\x60\x67\x1c\xb8\x5d\x93\x0e\x57\x0a\xf8\xa2\xf5\xdc\x79\x02\x8f\x5a\x70\x63\x1b\x39\xb4\xc4\xc4\x20\x92\x72\x29\xb8\xc9\xcf\xaa\x0a\x24\xd2\x37\xac\x51\x9a\xe9\x52\x6d\x13\x28\x60\x8d\x1f\xd8\xc1\x0c\x5c\x06\xec\x64\xb3\x85\x7b\x9e\xd5\x3c\x40\x52\x61\x45\xca\x34\xb6\x44\xc4\xaf\x08\xf8\xc4\x67\x4e\xd8\x9d\xf4\x9c\x70\x08\x57\x23\x77\x3c\x33\xde\xee\xf0\xec\x80\x78\x8e\xef\x04\xa1\x31\x9d\xf7\x0e\x3a\xa7\x33\xe4\x46\xdd\x04\x92\xd9\x5c\x14\x2b\xca\x5b\x2b\x26\xd2\x0a\xab\x2c\x84\xd2\xa6\xf8\x48\x3c\x67\xe0\xfa\x81\xe3\x85\xce\xc8\x76\x87\x21\x36\x18\xbd\xd1\x4e\x9f\x84\x1b\x1f\x69\x80\x98\x99\x0c\x48\x26\x8b\x29\x6a\x7a\xad\xdf\x2c\x8a\x64\x99\x99\x8e\x52\x53\xbd\x5d\x3f\x78\x27\xb3\xc4\x25\x62\x0e\xae\xc4\x02\xab\xae\x5a\x52\x44\xd9\x2c\x5b\xeb\x44\x64\x8b\x36\x81\xd4\xdf\xf5\x9c\xd0\x77\x07\x63\x77\x1c\x02\x76\x6e\x50\x18\xc1\x6e\x32\x59\xd5\x38\x1b\xe1\x7d\x3c\x09\xdc\xfe\xcb\x10\x76\xd3\x1c\x0e\x20\x27\xe6\x9a\x89\xf4\x31\x76\x0d\xd5\xe3\xfd\xfd\x85\xd0\x49\x79\xdd\x8e\xe4\x0a\x6c\x5b\x68\x85\x26\xbe\x2f\x94\x2a\xb9\xda\x3f\x3c\x3d\xd9\x64\x63\x1f\xd0\xaa\xcd\x4b\xde\x37\x76\xf2\x3e\x26\x54\x6a\x17\xb1\x5c\x47\x09\x83\xcc\x43\xc4\x46\xbd\xdf\x91\x52\x45\xbb\x6b\x4f\x83\xee\x85\xbd\x0d\x7e\xb7\xfc\x3a\x91\x72\x09\xae\x28\x40\xec\xdd\xc0\x94\xa6\x3d\x59\x3b\xa1\x52\xf1\x6d\x51\x0f\xb6\x09\x2e\x55\xa5\x2c\x5a\xc2\x45\x2c\x54\x24\x8b\xd8\x5c\x66\x0b\xcd\xd2\xe5\x1e\xa9\x21\x1e\x8c\xb6\x28\x8e\xb5\x68\x35\x12\x2e\xcc\x38\x72\x4e\x2f\xa4\x5c\x62\x2a\xff\x81\xba\x4f\xb5\x52\x40\x32\xf2\xbe\x6a\xcf\xfd\x05\x9e\x1e\x4f\xc5\x0d\x2f\xb0\x0a\x00\x59\x25\x18\x20\x8f\x64\x16\x2b\xd2\x73\x40\xf9\xbd\x30\x70\x47\xce\x64\x86\xa1\xe7\xa4\xae\x00\x53\x91\xa1\xe3\xe4\x8d\x32\x38\xb0\xd1\x7f\xea\x4e\xc3\x60\xe8\x87\xcf\x1c\xcf\xed\xbf\x6c\xc8\x62\xbc\x01\xa1\x89\x50\x98\x63\x35\x8a\x1a\x98\x0b\x01\xaa\xcd\xd9\x02\x42\xc2\xc0\x1d\x0f\xc2\xf1\x6c\xb4\x45\xa1\x22\xe5\xc5\xbb\x20\xe7\x9c\x3e\x29\xe7\x73\x2c\x1f\x23\x04\x00\x68\x99\xb0\x2c\xe3\xa9\x45\x97\x9c\xe7\x54\x60\xac\x11\x08\x43\x4c\x0f\x96\xc6\x98\x54\x2e\x33\x79\x4b\x6f\x01\xf9\xe1\xc3\x36\xf1\x9d\x71\x2f\x7c\x32\xeb\xf7\x1d\x0f\x98\x64\x38\x54\x55\xc0\xc4\x6b\x00\x2f\x39\xa0\x3a\x34\x79\xac\x9d\x94\xd7\x5f\x41\x04\x07\x20\x4c\xfc\xd9\x93\xdf\x76\xba\x41\x38\xf5\x9c\xbe\xfb\x82\x76\xe8\xab\xcb\x8f\x1f\xd4\xbd\xfc\x87\xea\x8a\xbe\xaa\x0d\xaa\xea\xa0\x9d\xd3\xc1\x0a\x2d\x45\xad\x74\xde\x5e\xc0\x35\x58\xc9\xe3\x93\xb3\x4f\xc9\x39\xfd\xe2\x8b\xea\xc1\xd7\x5f\xe3\xdd\x47\xa7\xc0\xf8\xb1\xd4\xdc\xaa\x13\x61\xec\x2a\xf0\x2c\xae\xd0\xe7\xde\xa3\xd3\x93\x3d\x8b\xfa\xa3\x60\x5a\xd5\x57\xae\xd1\xa9\xc6\x6d\x3a\xc3\x5e\x15\xf6\xe5\x82\xa1\x4f\x65\x66\xe6\x9e\x9c\x7d\x0a\x4c\x29\x38\x20\x4f\xb3\x33\xc8\x0b\xbc\x7e\x97\x9e\x3e\x3a\xf8\x6c\x53\xd2\xb9\x53\xf7\xdd\x12\x12\xba\x2a\xe4\xa4\xb7\x6c\xad\x36\xef\xab\x60\x4a\x23\x74\x5f\x38\xc3\x09\x95\x39\x37\x96\x66\xa0\x40\x22\x95\xc6\xd8\x02\xe6\x14\x0b\x90\x21\xcf\x74\x7b\x5b\x84\x83\x39\x40\xa4\x6b\x32\x85\xcd\x78\x30\xb9\x5d\x82\x3b\x50\x13\xbb\x34\xa6\x5a\xd4\x26\x30\x0e\x5b\xb9\x26\x28\xa0\xab\x45\x47\x6b\xb0\x8d\x69\x4a\x36\xba\x38\xb2\xb9\xe3\x36\x9d\x64\xe9\x1a\xa1\x8c\x4e\x84\xc9\x41\x15\x4f\xe7\x2d\xf0\xa7\x3c\x6e\x4e\x54\x46\xed\x6b\x95\x37\xde\x97\x46\xa9\x80\x24\xb6\x31\x0e\xf0\x59\xd8\x75\xbc\xc0\xed\x83\x6b\xdb\x06\xb2\x7b\x1a\x33\x46\xe3\x3f\xd4\x99\xa9\x46\x6c\x5b\x33\xa8\x5f\xa6\x81\x15\xc7\x05\x57\xca\x42\x69\x9e\x1c\x1f\x1d\x55\x45\xc3\xca\x3b\x61\xda\xc1\x32\xca\x31\x60\x6d\x06\xcb\x02\xb7\xff\x6a\x6f\xcc\x56\x7c\x8f\xfe\x18\x1f\x7f\xde\x68\x92\xfd\xe4\x15\x35\x16\x4b\xfa\xde\x64\x54\x55\x05\x60\x11\x5b\x78\x80\x41\x2b\x67\x4a\xdd\xca\x22\xae\xf0\x68\x13\x8a\x02\x63\x34\x7f\xad\xf7\xf3\x94\x09\xcc\x86\x0c\x45\xb4\x5c\x99\x69\xc8\x0f\x80\x4b\xd3\xa1\xed\x8e\xc3\xc0\x79\x11\x34\xa0\x5a\xc4\xa2\x64\x17\x6e\xf3\x95\x2c\xd6\x06\xba\xc6\x02\x1c\xae\x34\x77\x71\xe4\xde\x6e\xe7\xa3\x1a\x4c\xec\x9e\x3d\x0d\x10\xa6\x98\x3b\x35\x92\xad\x9e\x57\xf0\x78\xd0\x35\xc5\xe3\x1b\x96\x36\x7c\xe2\x0e\xc5\xd3\x03\xe2\x8e\x03\xc7\x7b\x66\x43\x1c\x3c\x3d\xa8\x09\x99\xb5\x18\x40\xdc\x58\xcb\xb6\xc7\x8d\xda\x5c\xf3\x9d\x9c\x53\x9c\xf0\x98\x66\xe6\xbc\x42\x47\x47\xb9\x05\x0f\x3b\x8f\x4f\x8f\x3f\xfd\xcc\xaa\xb9\xd9\x59\xb1\x88\x15\x32\xb3\xe2\xeb\xce\x81\x95\x4b\x99\x62\x16\xd3\x39\x3c\x38\xb0\x44\x9c\xf2\xb0\x72\xe1\x1d\x83\x51\xea\x37\x3f\xa6\xaf\xb6\x19\xc3\xe1\xe1\xd1\xe1\xe1\xab\xda\x44\x01\x17\xe1\x39\x9b\xfb\x79\x0a\xe9\x6b\xc5\xd2\x9a\xbd\xf7\xf1\xb3\x3e\x06\xd5\x64\xe8\xb4\x90\x37\x02\xf0\x23\x82\xa3\x05\x95\xb9\xc1\xe4\xe7\xd5\x90\xc7\x68\x86\xa6\xac\x98\xad\xeb\x51\x6b\xae\x21\xa9\x17\x29\x7f\x4c\xab\x95\x6d\x5b\x7f\x55\xc9\xc4\xd4\x5f\xaa\xa7\xea\xd5\xff\x33\xee\x41\xc6\xf5\x98\x2e\x64\x4b\x7d\x9d\xb6\xe2\x02\x62\xe4\x3e\xde\xa4\xb1\xca\xea\x05\x2b\x5d\x88\x6c\x51\xaf\x0c\xd2\xae\xc7\xf5\xfb\x3e\xaf\xd7\x18\x6a\x70\x82\xaf\x36\x6c\x0a\xab\x13\x66\x55\xca\x53\xef\x04\x4b\x0b\x66\xcb\x15\x3c\x46\xb4\xbd\x8b\x6a\x45\x98\x8a\x25\x0f\x0d\x94\x22\xe7\xe0\xa2\x21\xa2\x81\x8f\xaa\xf9\x05\x19\x38\x80\xaf\x4a\x8d\x9b\xae\xd1\xb8\x9a\xf7\x24\x03\x15\x54\xda\xc2\xf3\x9d\xb9\x08\x86\x2a\x88\x04\x08\x79\x03\xc4\xab\xba\x59\xbd\xf4\x41\x17\x81\xc4\xc6\x74\x76\x88\x1c\x9f\x1e\x1c\x90\x41\x37\xac\x8d\x06\x81\x05\xed\x98\xfb\x5b\x1a\xa9\x98\x9b\xa6\xc4\xce\xe4\xb3\xd3\x47\x07\x07\xc4\x77\xf0\xc0\x57\x38\x74\xfb\x4e\x3d\xdd\x3c\x39\xa7\xdd\x2d\xdb\xd0\x59\x77\x7d\xaf\x4f\xe0\xcf\x9d\xd4\x20\x8c\x54\x31\x27\xe4\x32\x17\x91\x2e\x0b\xf4\x27\x9b\xd3\x17\xa6\x84\xab\x36\xf5\x31\x1e\x53\x76\xc3\x34\x2b\x14\xb1\x9f\xd9\x81\xed\x85\xb3\xe9\x70\x62\xf7\x76\xca\xb4\xf5\x88\xbb\x74\x1a\xe5\xe4\x77\xa8\x79\xce\x74\xe2\xbb\xc1\xc4\x7b\x19\xbe\x9f\x30\x10\x68\x6d\xa9\x77\x13\x91\x71\xc5\x2b\xc4\x89\x55\x04\x73\xb8\x66\x2f\x2e\xa5\x4a\x4a\xb9\x67\x5a\x2d\xac\x2e\xaf\x99\xa9\x54\xc9\xb2\x88\xb8\x45\x41\x77\x0c\x34\x7f\xbc\xbf\x1f\x65\xed\x45\x61\x06\x20\x3c\x37\x97\xfb\x64\xe0\x55\xeb\xf1\x27\x33\xaf\x8b\xe9\x64\x35\x0c\x7b\xc2\xd8\x79\x4a\x4b\xbe\xc1\x18\x73\x59\x44\x9b\x02\x34\x1e\xbb\x10\x19\x95\xf3\x39\xd6\x07\x57\x78\x8a\xad\x8e\xe9\x35\xe9\x86\xd6\xf5\x79\x8c\x67\x39\x6a\xc6\xd0\x54\xca\x65\x99\xc3\x16\x15\xed\x8d\xfd\xaa\x96\x13\x49\x80\x20\xd5\x90\x6d\xe7\x81\x9c\x1b\xf0\x83\x81\x0a\x00\x34\xe7\x9b\xcc\xe3\xf6\xf6\xb6\x9d\x8a\xeb\x7a\x8b\xb2\x58\xfc\x80\xf5\xe3\xb2\xee\x6e\x00\x58\x3a\xa8\xe8\x80\x26\xc6\x42\x5d\xb3\x14\x90\x4e\x65\x10\x7d\xa7\xe7\x78\x76\xe0\xf4\xc2\x3b\xfb\xfb\x40\x35\xdb\x64\x40\xe4\xf2\xff\x93\x1a\xf6\xbd\x83\x7e\x50\x51\xfb\xd1\x6e\x4d\xfb\xd1\x6f\x58\xd2\x3e\xb9\xdb\x60\xb8\x04\xcf\x02\xbc\xf6\x73\x1e\x89\xb9\xe0\xe6\x18\x49\x85\x42\x80\x6d\xf3\x32\x4d\xd7\x54\x96\x3a\x2f\x41\x31\x63\x00\x78\xbb\x44\xbd\x7e\xf7\xf0\xf0\xe8\xb8\x26\xc2\xd2\x1a\x1d\xf3\xb8\xee\x6e\x81\xd4\xec\xb1\xef\x76\x2d\x3a\xcb\xc4\xeb\x1e\x03\xe8\xee\x95\xd7\xeb\xea\xaa\xdf\x3d\x3b\x3a\xaa\x3f\xbf\x34\x17\x27\x07\x56\x4d\x7a\x73\x61\x1e\x1d\x1f\x1f\x7f\xb6\xb9\x18\xb3\x4c\x5a\xf4\xa9\xd0\x51\xc2\x33\x8b\xfa\x9a\xad\xf2\xea\x63\x24\xd2\x54\x6c\xae\xa3\x42\x22\x08\xc1\xaf\x30\xab\x02\x28\x28\xca\x66\xf2\xc5\xae\x21\xf3\x6b\xb0\xa1\x36\x24\xc8\xe0\x65\xca\xb2\x05\xd8\xcf\x7e\xbe\x5c\xec\x03\xf7\xf6\x7f\x94\x2f\x17\xad\x48\x66\x4a\x33\xd0\x91\xfe\xc4\x1b\xd9\x81\x29\xdd\x9a\xc3\x59\xe9\x56\xd9\xe5\x9c\xe2\xb1\x97\x42\x91\xcb\x54\x2e\xae\xc8\xee\x69\x9c\x6e\x95\x2f\x03\x35\x99\xf2\x0a\x35\x55\xc8\xa3\x89\x36\xea\x01\x35\xb8\x96\xab\x15\x33\xf5\xa4\xaa\x1e\xbf\x2a\x53\x2d\xf2\xba\x6f\x59\x29\x67\x3d\xcd\x42\x35\xd9\x23\x55\x0d\xb3\xba\xfb\x7f\x33\x7d\xbc\x27\x73\xac\x11\x55\x50\xb0\x08\xeb\xab\x6e\x36\x97\xf0\xf9\x9c\x15\x19\x7c\x3a\x45\x21\x0b\xb8\xe8\x33\xcd\xd2\x3b\x1b\x36\xb3\xc8\xd0\x79\xe6\x00\xbc\xc4\xaf\xa4\x86\x98\x1b\x76\x19\x07\x95\xa5\x6b\xe4\x6e\xbb\xba\x0f\xfa\x9d\x36\xfa\x7c\x58\x69\x4b\x78\x21\x74\x4d\x6f\x43\x09\xf9\x72\x97\x0c\xdc\xfc\x01\x34\x2a\x87\x6a\xbc\x93\xaa\x3b\xfa\x3c\x06\x89\xd3\x42\x6a\x10\xcb\x03\x75\x0b\x9a\x8a\x96\x2a\xc1\x7d\x40\x32\x5a\xc1\xc1\x87\x64\x38\x19\x84\xde\x24\x30\xb9\xd0\x06\x4b\x2c\xd0\x5f\x02\x91\x98\x89\x74\x4d\x7a\xb6\x3b\x7c\xf9\xce\xb8\x8d\xf3\x50\x89\x98\x63\x02\x01\x89\x6e\x6a\x7a\xc4\x3b\xbc\x3c\x3a\xab\x3a\x9d\x87\xf4\xc7\x3f\xa6\x47\x67\x16\x3d\x3a\x39\x6d\xf8\x95\xd0\xbf\x70\xfb\x78\x6c\xf8\xac\xa2\x8b\xce\x7f\xeb\x63\x1a\x84\x71\xd2\xd0\x1d\x57\x1d\x32\xfc\x07\xb2\x7e\x9d\x8b\x02\xbd\xc5\xba\xd6\x79\x03\x5d\x1f\xc4\x3c\xe5\x9a\x53\x36\xd7\xbc\xa0\x2b\xf6\x1a\x87\x3c\x44\x32\x9b\x3a\xef\xa6\x98\x8e\xd5\xa2\xbb\xd2\xc0\xbb\x3f\x48\x1c\xcf\xab\x12\xd0\xcc\x1b\x12\x3c\x30\x4e\x0c\x85\xaa\xa4\xf4\x7f\x48\xc3\x14\x13\x11\x57\xc5\x42\xe5\x29\x5b\x9b\xd3\xd7\x55\xc1\x89\x34\xca\xd3\xcd\xa2\x47\xf5\xee\xd7\xb2\x58\x35\x9a\x87\xc8\x14\xd4\x0d\xac\x8d\xde\x91\xa9\x67\x94\xc6\xb4\xc5\x63\xb6\xae\x06\x84\xa8\x01\xef\x0c\x93\x59\x54\x11\x44\x3d\xe0\xaf\x23\xae\x00\x38\xbc\xa6\xbb\x41\xc3\x98\x63\xdd\x8c\x46\x11\x69\x69\x0c\xdc\xf8\x26\x13\x44\x9a\x32\x39\x86\x74\xb3\x90\xcd\xb6\x67\x51\x66\x19\x28\x2f\xdc\xae\x8e\xd5\xe4\xbc\x10\x32\x36\x47\x58\xee\x39\x25\xe0\x95\x59\x73\x34\x16\x3e\xb0\xf3\x6f\x2a\x73\x6d\xfc\x01\xc6\x3b\x67\xa6\xf1\x48\x64\x8c\x2e\x0d\xcf\x8b\x28\xb3\x92\xb6\xf9\xb9\x42\x58\xdd\xbc\x22\x7e\xf7\xc2\xe9\xcd\xb0\x22\xf0\xb9\x61\xd8\xe1\xc1\x8a\x60\x5d\x7f\x83\x3b\x13\xce\x52\x9d\x98\x43\xbd\x15\x19\x00\x95\xa1\xb9\x1f\xe2\xfd\xfb\x28\x1d\x3d\x4a\xc8\xb6\xec\x77\x7a\x00\x40\xc0\x2e\x16\xa5\x81\x24\x10\x25\xd1\x01\x67\x31\xfd\x64\x21\x34\x9d\xab\x68\xf9\x49\xed\x72\x5b\xad\x32\x2b\x20\x9a\x23\xd7\x5a\x2d\xcd\x16\x0a\xdc\x36\x04\x15\x0c\x3d\x32\xdb\x04\x17\xa1\x5b\x2a\x5a\x21\x00\x8d\x65\xa4\xf0\x06\x10\xdb\x3f\x6c\x7f\xda\x3e\x21\xb6\x37\xf0\x8d\xaf\xea\xe2\xb1\xe4\x06\xa2\xc6\x93\xa1\x4a\x8b\xa8\x66\x0f\xee\x25\xc4\xdd\xc1\x33\x75\x75\x97\xbb\x28\x94\xfb\xb7\x0a\x2f\x48\x39\xcb\xca\xbc\xf9\x0a\x56\x44\x89\xb8\xe1\xaa\xc9\xb8\xea\x5e\x18\x99\xe1\xef\xbc\xc4\x88\xf0\xfe\xb7\x9c\xd3\x00\x72\xa3\xfa\x54\xf2\xf6\xb4\xb5\x98\xd7\xef\x6a\xb4\xa1\xab\xd3\x22\x64\x32\x84\xa4\x31\xb8\xb0\x21\xb0\xe0\x62\x2f\x17\x42\x37\x5a\x63\x8a\x26\x62\x91\xa4\x62\x91\xa0\x13\x64\x31\xe6\x19\x59\x4c\x0b\xbe\x92\x37\xe6\x48\x65\xb6\xe0\xdb\x86\x58\xcf\xed\xf7\xc3\x0b\x77\x70\x31\x74\x07\x17\xc1\x4e\xc5\xbf\x09\xac\xc0\x07\xaa\x0d\xe4\x03\xca\x4d\x3f\x08\x0e\x20\x16\xf3\x39\xf6\x14\xd0\x72\x06\x6e\x60\x48\x37\xbd\xe3\x3b\x54\xa3\x84\x15\x2c\xd2\x90\xc1\x20\xc9\xb4\xd9\xe9\xfd\x30\x4d\x3c\x0e\x6a\x77\x03\xf3\x8b\x80\x93\x7b\x88\x1b\x2c\xa8\x12\x79\x9b\x7d\x80\xd6\xf6\x7c\xc3\xc1\x87\xd5\x7a\x11\x35\x94\x9a\x2d\x16\x05\x64\xa8\x37\xa0\xd3\x10\xea\x7e\x13\x9d\x5e\x44\x95\x46\x0f\xba\xe1\x56\xa9\x27\x9b\x9a\xe8\x3d\xd5\x77\x90\x72\xbb\xba\x7f\x45\xcc\xe1\x41\x07\x8d\xf1\xa0\x3a\x24\x6a\x7e\x31\x45\xba\xc3\xc9\xd8\xa9\xae\xa7\xb3\xe1\xb0\xba\x1c\x74\x4d\x51\x8a\x5c\x1a\x8f\x71\xd5\x38\x85\xdb\xac\x6c\x25\xb2\x2c\x14\xbd\xe6\xfa\x96\xf3\xaa\x08\x6f\xdc\x45\xcf\xe9\xdb\xb3\x61\x10\x36\x6a\x5c\x67\x84\x5c\xb2\x5c\x5c\xbd\xc3\x78\xa1\xf9\x4a\x99\x9c\xca\xfc\x42\xc0\xa4\x51\xcc\xd4\xf3\x81\xfb\xe6\x97\x76\xbe\x13\xba\x81\x33\x32\xf2\x23\xe4\xb2\x44\x5a\xdb\xd6\xc0\xce\x09\xcd\xcd\x89\x10\x10\xa8\xd1\x0e\x99\xe1\x89\xfc\x14\x58\x8e\xa4\x9d\x17\xd3\xe1\xc4\x73\xc2\x9d\x96\xc1\xd1\xc1\x0e\x51\x93\x6b\xbd\x8f\x1c\x92\x71\x7d\x7f\x76\x87\xc8\xe1\x2e\x91\xcd\xb1\xe1\xea\x44\xe6\x2e\x11\x16\x69\x71\x23\xf4\x9a\xce\x39\x8f\x49\xdf\x71\x7a\x78\x14\xca\x1c\x55\xac\x08\x9e\x6c\x8e\x50\xc8\x39\xdd\xd3\x09\x5f\xf1\x56\x24\x53\x59\xec\xd1\x15\xd7\x8c\x6a\xb6\xb0\xcc\x09\xd0\xeb\x35\xb5\xb3\xb8\x90\x22\xa6\x3f\xe9\xd0\x13\xfc\x01\x92\x0d\x1a\x8d\x0d\x2c\x8a\x93\x30\x9b\xa7\x7b\x99\xcc\xaa\x7e\x7d\xdd\xc7\x37\x52\x30\xbf\x15\x6a\xfc\x2e\x4d\xe9\x75\xba\x69\xd3\x01\xf8\xdf\x36\xe9\x62\x7e\xc3\x53\x99\xf3\x42\xb5\x17\x52\x2e\x4c\xad\x77\xff\x96\x5f\xef\x9b\x90\xa3\xf6\x8f\x0e\x0e\x1f\xed\x1f\x1e\xee\xfb\x26\xcd\x69\xcd\x65\xd1\x6a\x6c\xa0\x25\xb2\x56\x37\x29\xe4\x8a\xb7\x8e\x3f\xc3\x87\xd5\xf2\x49\x70\xe1\x8c\x9c\xb0\x3b\x19\x4e\xbc\x70\xe4\x04\x76\x18\xd8\x03\xda\xa1\xaf\x7e\x34\x9f\x9f\x1c\x3f\x3a\x7e\xd5\x84\x71\x22\xa3\xd7\x6b\xcd\xd5\xd6\x90\x4d\x52\xbe\xc5\x1c\x0f\x9a\xf5\xa0\xd1\x93\x0a\x44\xb9\xfe\x74\x68\x9b\xe2\x78\x1d\xf0\xcf\x8e\xcf\xce\x4e\x0f\xce\x50\xc1\xda\x9b\xa3\x04\x5b\x61\x56\x3d\xbb\x0f\x28\x04\x60\x9a\x5d\x7d\x38\x39\x78\x57\x53\x3f\x48\xc2\x73\xa6\x93\x0f\x92\xc8\xa4\x16\xd1\xaf\x51\xcc\xf1\x24\x70\xbb\x77\xd5\xfb\x64\x87\x4c\xf3\xd4\xc3\x07\x69\x4d\xbc\xc1\x3b\xeb\x41\x0e\x01\x3b\xee\xb1\xc3\xdf\x70\x77\x87\xbb\xcb\xca\xf8\xad\x42\x73\xf8\x35\x1b\x74\x9e\xfb\x21\x1a\xcc\x87\x4c\xb8\xb6\xba\x0f\x51\xaa\xcf\x05\xef\xd0\x39\x86\x2d\x8a\xc3\xb3\xec\x8a\x0c\xed\x31\x38\x5e\xca\xb3\xd6\xcc\xb7\xbe\x49\x5a\xdd\x31\xfc\xbd\x78\x0a\x7f\x83\xe7\x56\xcc\x5b\x3d\xc7\x9a\x17\xad\xbe\x67\x65\x69\x6b\x3c\xb4\xd2\x9b\xd6\xf0\x99\x55\x94\x2d\x6f\x66\x7d\xc5\x5a\xbf\x3d\xb5\xb8\x6a\x39\xbe\x95\xeb\xd6\x13\xcf\xca\xd3\xd6\x74\x68\x5d\x2f\x5a\x4f\x06\x96\xd0\x2d\x37\xb0\xe6\xa2\xd5\x77\x2d\x5d\xb4\x02\xcf\x8a\x54\xab\xfb\xa5\xa5\x8a\x96\x3f\xb5\xd4\x4d\xcb\x77\xac\xa5\x6c\x3d\xf5\xac\x45\x0a\x14\xca\x65\x6b\x66\x5b\x3c\x6b\x0d\x9e\x58\x49\xd9\xba\x98\x59\x6a\xd9\xf2\x9f\x5a\x22\x6e\xb9\x3d\x6b\xce\x5a\xae\x67\xdd\x88\xd6\xb3\x31\x1e\xef\x81\x55\x3b\xd9\x22\x15\x2a\xb1\x7e\xf5\x1f\xbf\xfd\x9b\xbf\xfc\xe7\x7f\xf3\xb3\x3f\xfb\xe5\x1f\xfc\x9e\xf5\xab\xbf\xf8\xee\xef\xfe\xfd\xbf\x30\x5f\xfe\xfe\x17\xff\xf8\xef\xfe\xdd\xbf\xfa\xe5\xcf\xfe\xd3\xdf\xff\xe2\x9f\xdc\x7d\xf0\xb7\xbf\xf7\xf3\x5f\x7d\xf7\x6f\xe0\x41\x8f\x97\x5a\x45\x89\x35\x2f\x58\xf6\xfd\x9f\x30\xa1\xac\x31\x8f\x79\x91\xb2\x2c\x56\x56\xca\xf4\x8d\xe0\x7f\xfd\xc7\xa5\xf5\xf6\xdb\xb7\xbf\xfb\xf6\xbb\xb7\xdf\xbd\xf9\xf9\x9b\x9f\xbd\xf9\x0b\xeb\x97\x7f\xf8\x6f\x7f\xf9\x47\xff\xe1\x6f\xff\xf4\x5f\x5b\x5c\xe5\xec\xfb\x3f\x97\xa9\x05\x7e\xa0\x5c\x94\xdf\xff\xa9\xa2\xb1\xa4\x4f\x0a\xa6\x04\xdc\x4c\xd5\x52\x58\x6f\xfe\xfc\xed\x3f\x7d\xf3\xdf\xde\xfc\xe7\x37\x3f\x7d\xfb\xad\xa1\x61\x09\xcd\x52\xc1\x32\x69\xa9\x52\xae\x84\x15\x7c\xff\x8b\x62\xf9\xfd\x9f\x70\xeb\xaf\x7e\x9f\xff\xf5\x1f\x6b\x91\x31\xeb\xed\x77\x6f\xbf\x7d\xf3\xdf\xab\xe1\xea\x86\x67\x6a\xc9\xac\xff\xf5\x2f\xff\xe8\x7f\xfc\xd7\x3f\xfb\x9f\x7f\xf0\x5f\xac\x05\x4b\xf9\x42\x5a\x6f\x7f\xf7\xcd\xcf\xdf\x7e\xfb\xe6\xa7\x6f\xff\xf0\xcd\x5f\xbe\xfd\xee\xed\x3f\x7b\xf3\xf3\x37\x3f\xb5\x2a\xde\xd0\x07\xb3\x0c\x4f\xec\x3d\x15\xd9\x22\x96\xab\x87\xd6\x88\x2d\xd6\xac\xb0\xfc\x54\xde\xf0\xec\xaf\x7e\x1f\x5e\xe3\x66\xb1\xcc\xb8\x12\x2c\xb3\xa6\xbc\xc0\xcf\x67\x82\x63\x6f\xb1\xc2\xde\xaa\x6a\xec\x83\xeb\x83\xf8\x9b\x8b\x68\xc9\x0b\xa3\x45\x6d\xb8\x99\xb2\x6c\x71\x45\x50\x8d\x50\x9d\x08\xea\x12\xed\xd0\x6f\x12\x82\x0a\x85\x97\xad\xe0\x39\xc1\xbf\x9b\x6f\xa8\x60\xf8\x5b\x6b\x82\x5a\x06\xc8\xab\x20\xa8\x6a\xb4\x43\xb3\x94\xa0\xbe\xd1\x0e\x4d\x6f\x08\x2a\x1d\xed\xd0\xa2\x24\xa8\x79\xb4\x43\xbf\x62\x04\xd5\x0f\xde\xa9\x08\xea\x20\xed\x50\xfc\x24\xa8\x8b\xf0\x2d\x25\xa8\x90\xb4\x43\xaf\x17\x04\xb5\x92\x76\xa8\xd0\x04\x55\x13\x5e\x28\x08\xea\x27\xe2\x61\x82\x4a\x4a\x3b\x14\x3f\x09\x2a\x2b\xed\x50\x55\x10\xd4\x58\xb8\xbc\x21\xa8\xb6\xb4\x43\x97\x92\xa0\xee\xd2\x0e\x5d\xa4\x04\x15\x98\x76\x68\xb9\x24\xa8\xc5\xc6\xae\x06\x4f\x08\x6a\x33\xed\xd0\xa4\x24\xa8\xd2\x40\x64\x49\x50\xaf\x61\x25\x31\x41\xe5\x46\xd0\x49\x50\xc3\x69\x87\xde\x08\x82\x29\x74\x7d\x46\x72\xc5\xf2\x1c\x7f\x61\x28\x1b\xd0\x36\x4a\x19\x36\xcb\x10\x8f\xb5\xb5\x5c\xa5\x1d\x91\x09\x72\xb9\x19\xd1\xae\xa6\x5d\x11\x72\x29\x75\x02\x2e\xcd\xbf\x98\x3c\x0f\xfb\x93\x49\xe0\x78\xe1\x13\xcf\xfc\xa8\xaa\x81\x77\xfd\x44\xde\x6e\x7e\xc4\xf6\x6e\x41\x0c\x53\x35\x00\x83\x03\x59\x9f\xe2\x9f\x4b\xa9\x79\xb1\x43\x77\xfb\x8b\xb6\xba\x7e\x01\x54\xb1\x0b\xd2\xfc\x35\x9b\xf9\x51\x5a\xd5\xa1\x79\x0f\xa9\xc0\x19\x4d\x87\x90\xee\x62\x27\xa0\x6a\x6f\x20\xd5\xff\x1d\x00\x00\xff\xff\xf7\xe9\xcd\x1e\xee\x40\x00\x00")
func confAppIniBytes() ([]byte, error) {
return bindataRead(
@@ -315,7 +315,7 @@ func confAppIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/app.ini", size: 16528, mode: os.FileMode(420), modTime: time.Unix(1524776408, 0)}
+ info := bindataFileInfo{name: "conf/app.ini", size: 16622, mode: os.FileMode(420), modTime: time.Unix(1529238130, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4375,7 +4375,7 @@ func confLocaleLocale_bgBgIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_bg-BG.ini", size: 96052, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_bg-BG.ini", size: 96052, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4395,7 +4395,7 @@ func confLocaleLocale_csCzIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_cs-CZ.ini", size: 69911, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_cs-CZ.ini", size: 69911, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4415,7 +4415,7 @@ func confLocaleLocale_deDeIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_de-DE.ini", size: 70417, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_de-DE.ini", size: 70417, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4435,7 +4435,7 @@ func confLocaleLocale_enGbIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_en-GB.ini", size: 62960, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_en-GB.ini", size: 62960, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4455,7 +4455,7 @@ func confLocaleLocale_enUsIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_en-US.ini", size: 65752, mode: os.FileMode(420), modTime: time.Unix(1528720535, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_en-US.ini", size: 65752, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4475,7 +4475,7 @@ func confLocaleLocale_esEsIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_es-ES.ini", size: 70688, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_es-ES.ini", size: 70688, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4495,7 +4495,7 @@ func confLocaleLocale_faIrIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_fa-IR.ini", size: 89605, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_fa-IR.ini", size: 89605, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4515,7 +4515,7 @@ func confLocaleLocale_fiFiIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_fi-FI.ini", size: 67461, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_fi-FI.ini", size: 67461, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4535,7 +4535,7 @@ func confLocaleLocale_frFrIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_fr-FR.ini", size: 71673, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_fr-FR.ini", size: 71673, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4555,7 +4555,7 @@ func confLocaleLocale_glEsIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_gl-ES.ini", size: 68976, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_gl-ES.ini", size: 68976, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4575,7 +4575,7 @@ func confLocaleLocale_huHuIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_hu-HU.ini", size: 70404, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_hu-HU.ini", size: 70404, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4595,7 +4595,7 @@ func confLocaleLocale_idIdIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_id-ID.ini", size: 65687, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_id-ID.ini", size: 65687, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4615,7 +4615,7 @@ func confLocaleLocale_itItIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_it-IT.ini", size: 67540, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_it-IT.ini", size: 67540, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4635,7 +4635,7 @@ func confLocaleLocale_jaJpIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_ja-JP.ini", size: 80072, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_ja-JP.ini", size: 80072, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4655,7 +4655,7 @@ func confLocaleLocale_koKrIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_ko-KR.ini", size: 70600, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_ko-KR.ini", size: 70600, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4675,7 +4675,7 @@ func confLocaleLocale_lvLvIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_lv-LV.ini", size: 70419, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_lv-LV.ini", size: 70419, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4695,7 +4695,7 @@ func confLocaleLocale_nlNlIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_nl-NL.ini", size: 66338, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_nl-NL.ini", size: 66338, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4715,7 +4715,7 @@ func confLocaleLocale_plPlIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_pl-PL.ini", size: 68798, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_pl-PL.ini", size: 68798, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4735,7 +4735,7 @@ func confLocaleLocale_ptBrIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_pt-BR.ini", size: 68954, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_pt-BR.ini", size: 68954, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4755,7 +4755,7 @@ func confLocaleLocale_ruRuIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_ru-RU.ini", size: 100048, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_ru-RU.ini", size: 100048, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4775,7 +4775,7 @@ func confLocaleLocale_skSkIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_sk-SK.ini", size: 70091, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_sk-SK.ini", size: 70091, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4795,7 +4795,7 @@ func confLocaleLocale_srSpIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_sr-SP.ini", size: 92384, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_sr-SP.ini", size: 92384, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4815,7 +4815,7 @@ func confLocaleLocale_svSeIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_sv-SE.ini", size: 66320, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_sv-SE.ini", size: 66320, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4835,7 +4835,7 @@ func confLocaleLocale_trTrIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_tr-TR.ini", size: 68843, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_tr-TR.ini", size: 68843, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4855,7 +4855,7 @@ func confLocaleLocale_ukUaIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_uk-UA.ini", size: 97728, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_uk-UA.ini", size: 97728, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4875,7 +4875,7 @@ func confLocaleLocale_viVnIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_vi-VN.ini", size: 74643, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_vi-VN.ini", size: 74643, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4895,7 +4895,7 @@ func confLocaleLocale_zhCnIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_zh-CN.ini", size: 62329, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_zh-CN.ini", size: 62329, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4915,7 +4915,7 @@ func confLocaleLocale_zhHkIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_zh-HK.ini", size: 62684, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_zh-HK.ini", size: 62684, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
@@ -4935,7 +4935,7 @@ func confLocaleLocale_zhTwIni() (*asset, error) {
return nil, err
}
- info := bindataFileInfo{name: "conf/locale/locale_zh-TW.ini", size: 62134, mode: os.FileMode(420), modTime: time.Unix(1528154969, 0)}
+ info := bindataFileInfo{name: "conf/locale/locale_zh-TW.ini", size: 62134, mode: os.FileMode(420), modTime: time.Unix(1528723789, 0)}
a := &asset{bytes: bytes, info: info}
return a, nil
}
diff --git a/public/css/gogs.css b/public/css/gogs.css
index abfd9ae5..17b84a1f 100644
--- a/public/css/gogs.css
+++ b/public/css/gogs.css
@@ -350,6 +350,9 @@ footer .ui.language .menu {
.center {
text-align: center;
}
+.no-padding-left {
+ padding-left: 0 !important;
+}
.img-1 {
width: 2px !important;
height: 2px !important;
diff --git a/public/less/_base.less b/public/less/_base.less
index 1f3b0c88..4f4c1ed5 100644
--- a/public/less/_base.less
+++ b/public/less/_base.less
@@ -388,6 +388,10 @@ footer {
text-align: center;
}
+.no-padding-left {
+ padding-left: 0 !important;
+}
+
.generate-img(16);
.generate-img(@n, @i: 1) when (@i =< @n) {
.img-@{i} {
diff --git a/public/less/_dashboard.less b/public/less/_dashboard.less
index 688a023b..f00a271a 100644
--- a/public/less/_dashboard.less
+++ b/public/less/_dashboard.less
@@ -143,27 +143,17 @@
max-width: 70%;
margin-bottom: -4px;
}
- .ui.micro.image {
- width: 16px;
- height: auto;
- display: inline-block;
- }
}
#collaborative-repo-list {
.owner-and-repo {
- max-width: 75%;
+ max-width: 80%;
margin-bottom: -5px;
}
.owner-name {
max-width: 120px;
margin-bottom: -5px;
}
- .ui.micro.image {
- width: 16px;
- height: auto;
- display: inline-block;
- }
}
}
}
diff --git a/routes/repo/setting.go b/routes/repo/setting.go
index da9d8fe4..e7844b3a 100644
--- a/routes/repo/setting.go
+++ b/routes/repo/setting.go
@@ -6,13 +6,13 @@ package repo
import (
"fmt"
+ "io/ioutil"
"strings"
"time"
- "io/ioutil"
- log "gopkg.in/clog.v1"
"github.com/Unknwon/com"
"github.com/gogs/git-module"
+ log "gopkg.in/clog.v1"
"github.com/gogs/gogs/models"
"github.com/gogs/gogs/models/errors"
@@ -296,6 +296,63 @@ func SettingsPost(c *context.Context, f form.RepoSetting) {
}
}
+func SettingsAvatar(c *context.Context) {
+ c.Title("settings.avatar")
+ c.PageIs("SettingsAvatar")
+ c.Success(SETTINGS_REPO_AVATAR)
+}
+
+func SettingsAvatarPost(c *context.Context, f form.Avatar) {
+ f.Source = form.AVATAR_LOCAL
+ if err := UpdateAvatarSetting(c, f, c.Repo.Repository); err != nil {
+ c.Flash.Error(err.Error())
+ } else {
+ c.Flash.Success(c.Tr("settings.update_avatar_success"))
+ }
+ c.SubURLRedirect(c.Repo.RepoLink + "/settings")
+}
+
+func SettingsDeleteAvatar(c *context.Context) {
+ if err := c.Repo.Repository.DeleteAvatar(); err != nil {
+ c.Flash.Error(fmt.Sprintf("Failed to delete avatar: %v", err))
+ }
+ c.SubURLRedirect(c.Repo.RepoLink + "/settings")
+}
+
+// FIXME: limit upload size
+func UpdateAvatarSetting(c *context.Context, f form.Avatar, ctxRepo *models.Repository) error {
+ ctxRepo.UseCustomAvatar = true
+ if f.Avatar != nil {
+ r, err := f.Avatar.Open()
+ if err != nil {
+ return fmt.Errorf("open avatar reader: %v", err)
+ }
+ defer r.Close()
+
+ data, err := ioutil.ReadAll(r)
+ if err != nil {
+ return fmt.Errorf("read avatar content: %v", err)
+ }
+ if !tool.IsImageFile(data) {
+ return errors.New(c.Tr("settings.uploaded_avatar_not_a_image"))
+ }
+ if err = ctxRepo.UploadAvatar(data); err != nil {
+ return fmt.Errorf("upload avatar: %v", err)
+ }
+ } else {
+ // No avatar is uploaded and reset setting back.
+ if !com.IsFile(ctxRepo.CustomAvatarPath()) {
+ ctxRepo.UseCustomAvatar = false
+ }
+ }
+
+ if err := models.UpdateRepository(ctxRepo, false); err != nil {
+ return fmt.Errorf("update repository: %v", err)
+ }
+
+ return nil
+}
+
func SettingsCollaboration(c *context.Context) {
c.Data["Title"] = c.Tr("repo.settings")
c.Data["PageIsSettingsCollaboration"] = true
@@ -635,56 +692,3 @@ func DeleteDeployKey(c *context.Context) {
"redirect": c.Repo.RepoLink + "/settings/keys",
})
}
-
-func SettingsAvatar(c *context.Context) {
- c.Title("settings.avatar")
- c.PageIs("SettingsAvatar")
- c.Success(SETTINGS_REPO_AVATAR)
-}
-
-func SettingsAvatarPost(c *context.Context, f form.Avatar) {
- f.Source = form.AVATAR_LOCAL
- if err := UpdateAvatarSetting(c, f); err != nil {
- c.Flash.Error(err.Error())
- } else {
- c.Flash.Success(c.Tr("settings.update_avatar_success"))
- }
- c.SubURLRedirect(c.Repo.RepoLink + "/settings")
-}
-
-func SettingsDeleteAvatar(c *context.Context) {
- if err := c.Repo.Repository.DeleteAvatar(); err != nil {
- c.Flash.Error(fmt.Sprintf("DeleteAvatar: %v", err))
- }
- c.SubURLRedirect(c.Repo.RepoLink + "/settings")
-}
-
-// FIXME: limit size.
-func UpdateAvatarSetting(c *context.Context, f form.Avatar) error {
- ctxRepo := c.Repo.Repository;
- if f.Avatar != nil {
- r, err := f.Avatar.Open()
- if err != nil {
- return fmt.Errorf("Avatar.Open: %v", err)
- }
- defer r.Close()
-
- data, err := ioutil.ReadAll(r)
- if err != nil {
- return fmt.Errorf("ioutil.ReadAll: %v", err)
- }
- if !tool.IsImageFile(data) {
- return errors.New(c.Tr("settings.uploaded_avatar_not_a_image"))
- }
- if err = ctxRepo.UploadAvatar(data); err != nil {
- return fmt.Errorf("UploadAvatar: %v", err)
- }
- } else {
- // No avatar is uploaded but setting has been changed to enable
- // No random avatar here.
- if !com.IsFile(ctxRepo.CustomAvatarPath()) {
- log.Trace("No avatar was uploaded for repo: %d. Default icon will appear instead.", ctxRepo.ID)
- }
- }
- return nil
-}
diff --git a/routes/user/setting.go b/routes/user/setting.go
index b893f35a..2391fb98 100644
--- a/routes/user/setting.go
+++ b/routes/user/setting.go
@@ -111,7 +111,7 @@ func SettingsPost(c *context.Context, f form.UpdateProfile) {
c.SubURLRedirect("/user/settings")
}
-// FIXME: limit size.
+// FIXME: limit upload size
func UpdateAvatarSetting(c *context.Context, f form.Avatar, ctxUser *models.User) error {
ctxUser.UseCustomAvatar = f.Source == form.AVATAR_LOCAL
if len(f.Gravatar) > 0 {
@@ -122,32 +122,32 @@ func UpdateAvatarSetting(c *context.Context, f form.Avatar, ctxUser *models.User
if f.Avatar != nil && f.Avatar.Filename != "" {
r, err := f.Avatar.Open()
if err != nil {
- return fmt.Errorf("Avatar.Open: %v", err)
+ return fmt.Errorf("open avatar reader: %v", err)
}
defer r.Close()
data, err := ioutil.ReadAll(r)
if err != nil {
- return fmt.Errorf("ioutil.ReadAll: %v", err)
+ return fmt.Errorf("read avatar content: %v", err)
}
if !tool.IsImageFile(data) {
return errors.New(c.Tr("settings.uploaded_avatar_not_a_image"))
}
if err = ctxUser.UploadAvatar(data); err != nil {
- return fmt.Errorf("UploadAvatar: %v", err)
+ return fmt.Errorf("upload avatar: %v", err)
}
} else {
// No avatar is uploaded but setting has been changed to enable,
// generate a random one when needed.
if ctxUser.UseCustomAvatar && !com.IsFile(ctxUser.CustomAvatarPath()) {
if err := ctxUser.GenerateRandomAvatar(); err != nil {
- log.Error(4, "GenerateRandomAvatar[%d]: %v", ctxUser.ID, err)
+ log.Error(2, "generate random avatar [%d]: %v", ctxUser.ID, err)
}
}
}
if err := models.UpdateUser(ctxUser); err != nil {
- return fmt.Errorf("UpdateUser: %v", err)
+ return fmt.Errorf("update user: %v", err)
}
return nil
@@ -171,7 +171,7 @@ func SettingsAvatarPost(c *context.Context, f form.Avatar) {
func SettingsDeleteAvatar(c *context.Context) {
if err := c.User.DeleteAvatar(); err != nil {
- c.Flash.Error(fmt.Sprintf("DeleteAvatar: %v", err))
+ c.Flash.Error(fmt.Sprintf("Failed to delete avatar: %v", err))
}
c.SubURLRedirect("/user/settings/avatar")
diff --git a/templates/.VERSION b/templates/.VERSION
index 95a1ce39..94f0604e 100644
--- a/templates/.VERSION
+++ b/templates/.VERSION
@@ -1 +1 @@
-0.11.57.0617 \ No newline at end of file
+0.11.58.0617
diff --git a/templates/explore/repo_list.tmpl b/templates/explore/repo_list.tmpl
index 413cdc53..f215c21c 100644
--- a/templates/explore/repo_list.tmpl
+++ b/templates/explore/repo_list.tmpl
@@ -2,31 +2,29 @@
{{range .Repos}}
<div class="item">
<div class="ui grid">
- <div class="ui two wide column middle aligned">
+ <div class="ui two wide column middle aligned center">
{{if .RelAvatarLink}}<img class="ui tiny image" src="{{.RelAvatarLink}}">{{else}}<i class="mega-octicon octicon-repo"></i>{{end}}
</div>
- <div class="ui fourteen wide column">
- <div class="ui header">
- <a class="name" href="{{AppSubURL}}/{{if .Owner}}{{.Owner.Name}}{{else if $.Org}}{{$.Org.Name}}{{else}}{{$.Owner.Name}}{{end}}/{{.Name}}">{{if $.PageIsExplore}}{{.Owner.Name}} / {{end}}{{.Name}}</a>
- {{if .IsPrivate}}
- <span class="text gold"><i class="octicon octicon-lock"></i></span>
- {{else if .IsFork}}
- <span><i class="octicon octicon-repo-forked"></i></span>
- {{else if .IsMirror}}
- <span><i class="octicon octicon-repo-clone"></i></span>
- {{else}}
- <span class="text"><i class="octicon octicon-globe"></i></span>
- {{end}}
+ <div class="ui fourteen wide column no-padding-left">
+ <div class="ui header">
+ <a class="name" href="{{AppSubURL}}/{{if .Owner}}{{.Owner.Name}}{{else if $.Org}}{{$.Org.Name}}{{else}}{{$.Owner.Name}}{{end}}/{{.Name}}">{{if $.PageIsExplore}}{{.Owner.Name}} / {{end}}{{.Name}}</a>
+ {{if .IsPrivate}}
+ <span class="text gold"><i class="octicon octicon-lock"></i></span>
+ {{else if .IsFork}}
+ <span><i class="octicon octicon-repo-forked"></i></span>
+ {{else if .IsMirror}}
+ <span><i class="octicon octicon-repo-clone"></i></span>
+ {{end}}
- <div class="ui right metas">
- <span class="text grey"><i class="octicon octicon-star"></i> {{.NumStars}}</span>
- <span class="text grey"><i class="octicon octicon-git-branch"></i> {{.NumForks}}</span>
+ <div class="ui right metas">
+ <span class="text grey"><i class="octicon octicon-star"></i> {{.NumStars}}</span>
+ <span class="text grey"><i class="octicon octicon-git-branch"></i> {{.NumForks}}</span>
+ </div>
+ </div>
+ {{if .Description}}<p class="has-emoji">{{.Description | Str2html}}</p>{{end}}
+ <p class="time">{{$.i18n.Tr "org.repo_updated"}} {{TimeSince .Updated $.i18n.Lang}}</p>
</div>
</div>
- {{if .Description}}<p class="has-emoji">{{.Description | Str2html}}</p>{{end}}
- <p class="time">{{$.i18n.Tr "org.repo_updated"}} {{TimeSince .Updated $.i18n.Lang}}</p>
- </div>
- </div>
</div>
{{end}}
</div>
diff --git a/templates/org/team/repositories.tmpl b/templates/org/team/repositories.tmpl
index e2cfbe95..4f1ad313 100644
--- a/templates/org/team/repositories.tmpl
+++ b/templates/org/team/repositories.tmpl
@@ -17,7 +17,6 @@
<a class="ui red small button right" href="{{$.OrgLink}}/teams/{{$.Team.LowerName}}/action/repo/remove?repoid={{.ID}}">{{$.i18n.Tr "org.teams.remove_repo"}}</a>
{{end}}
<a class="member" href="{{AppSubURL}}/{{$.Org.Name}}/{{.Name}}">
- <img height="16px" class="octicon" src="{{.RelAvatarLink}}" />
<i class="octicon octicon-{{if .IsPrivate}}lock{{else if .IsFork}}repo-forked{{else if .IsMirror}}repo-clone{{else}}repo{{end}}"></i>
<strong>{{$.Org.Name}}/{{.Name}}</strong>
</a>
diff --git a/templates/repo/header.tmpl b/templates/repo/header.tmpl
index 1bef1903..561f7f5d 100644
--- a/templates/repo/header.tmpl
+++ b/templates/repo/header.tmpl
@@ -5,8 +5,12 @@
<div class="column"><!-- start column -->
<div class="ui header">
<div class="ui huge breadcrumb">
- {{if .RelAvatarLink}}<img class="ui mini spaced image" src="{{.RelAvatarLink}}">{{else}}<i class="mega-octicon octicon-repo"></i>{{end}}
- <i class="mega-octicon octicon-{{if .IsPrivate}}lock{{else if .IsMirror}}repo-clone{{else if .IsFork}}repo-forked{{else}}globe{{end}}"></i>
+ {{if .UseCustomAvatar}}
+ <img class="ui mini spaced image" src="{{.RelAvatarLink}}">
+ <i class="{{if .IsPrivate}}mega-octicon octicon-lock{{else if .IsMirror}}mega-octicon octicon-repo-clone{{else if .IsFork}}mega-octicon octicon-repo-forked{{end}}"></i>
+ {{else}}
+ <i class="mega-octicon octicon-{{if .IsPrivate}}lock{{else if .IsMirror}}repo-clone{{else if .IsFork}}repo-forked{{else}}repo{{end}}"></i>
+ {{end}}
<a href="{{AppSubURL}}/{{.Owner.Name}}">{{.Owner.Name}}</a>
<div class="divider"> / </div>
<a href="{{$.RepoLink}}">{{.Name}}</a>
diff --git a/templates/repo/settings/options.tmpl b/templates/repo/settings/options.tmpl
index 8aa4a1f7..f380e984 100644
--- a/templates/repo/settings/options.tmpl
+++ b/templates/repo/settings/options.tmpl
@@ -41,7 +41,6 @@
<div class="field">
<button class="ui green button">{{$.i18n.Tr "repo.settings.update_settings"}}</button>
</div>
-
</form>
<div class="ui divider"></div>
diff --git a/templates/user/dashboard/dashboard.tmpl b/templates/user/dashboard/dashboard.tmpl
index f9f97447..4a0c90a2 100644
--- a/templates/user/dashboard/dashboard.tmpl
+++ b/templates/user/dashboard/dashboard.tmpl
@@ -32,8 +32,7 @@
{{range .Repos}}
<li {{if .IsPrivate}}class="private"{{end}}>
<a href="{{AppSubURL}}/{{$.ContextUser.Name}}/{{.Name}}">
- {{if .RelAvatarLink}}<img class="ui micro image" src="{{.RelAvatarLink}}" />{{else}}<i class="octicon octicon-repo"></i>{{end}}
- <i class="octicon octicon-{{if .IsFork}}repo-forked{{else if .IsPrivate}}lock{{else if .IsMirror}}repo-clone{{else}}globe{{end}}"></i>
+ <i class="octicon octicon-{{if .IsFork}}repo-forked{{else if .IsPrivate}}lock{{else if .IsMirror}}repo-clone{{else}}repo{{end}}"></i>
<strong class="text truncate item-name">{{.Name}}</strong>
<span class="ui right text light grey">
{{.NumStars}} <i class="octicon octicon-star rear"></i>
@@ -58,8 +57,7 @@
{{range .CollaborativeRepos}}
<li {{if .IsPrivate}}class="private"{{end}}>
<a href="{{AppSubURL}}/{{.Owner.Name}}/{{.Name}}">
- {{if .RelAvatarLink}}<img class="ui micro image" src="{{.RelAvatarLink}}" />{{else}}<i class="octicon octicon-repo"></i>{{end}}
- <i class="octicon octicon-{{if .IsPrivate}}lock{{else if .IsFork}}repo-forked{{else if .IsMirror}}repo-clone{{else}}globe{{end}}"></i>
+ <i class="octicon octicon-{{if .IsPrivate}}lock{{else if .IsFork}}repo-forked{{else if .IsMirror}}repo-clone{{else}}repo{{end}}"></i>
<span class="text truncate owner-and-repo">
<span class="text truncate owner-name">{{.Owner.Name}}</span> / <strong>{{.Name}}</strong>
</span>
@@ -90,7 +88,6 @@
{{range .ContextUser.Orgs}}
<li>
<a href="{{AppSubURL}}/{{.Name}}">
- {{if .RelAvatarLink}}<img class="ui micro image" src="{{.RelAvatarLink}}" />{{else}}<i class="octicon octicon-repo"></i>{{end}}
<i class="octicon octicon-organization"></i>
<strong class="text truncate item-name">{{.Name}}</strong>
<span class="ui right text light grey">
@@ -119,7 +116,6 @@
{{range .Mirrors}}
<li {{if .IsPrivate}}class="private"{{end}}>
<a href="{{AppSubURL}}/{{$.ContextUser.Name}}/{{.Name}}">
- {{if .RelAvatarLink}}<img class="ui micro image" src="{{.RelAvatarLink}}" />{{else}}<i class="octicon octicon-repo"></i>{{end}}
<i class="octicon octicon-repo-clone"></i>
<strong class="text truncate item-name">{{.Name}}</strong>
<span class="ui right text light grey">
diff --git a/models/repo.go b/models/repo.go
index 3a9f388b..c39d715f 100644
--- a/models/repo.go
+++ b/models/repo.go
@@ -7,6 +7,9 @@ package models
import (
"bytes"
"fmt"
+ "image"
+ _ "image/jpeg"
+ "image/png"
"io/ioutil"
"os"
"os/exec"
@@ -15,15 +18,12 @@ import (
"sort"
"strings"
"time"
- "image"
- _ "image/jpeg"
- "image/png"
"github.com/Unknwon/cae/zip"
"github.com/Unknwon/com"
"github.com/go-xorm/xorm"
- "github.com/nfnt/resize"
"github.com/mcuadros/go-version"
+ "github.com/nfnt/resize"
log "gopkg.in/clog.v1"
"gopkg.in/ini.v1"
@@ -39,6 +39,9 @@ import (
"github.com/gogs/gogs/pkg/sync"
)
+// REPO_AVATAR_URL_PREFIX is used to identify a URL is to access repository avatar.
+const REPO_AVATAR_URL_PREFIX = "repo-avatars"
+
var repoWorkingPool = sync.NewExclusivePool()
var (
@@ -146,16 +149,18 @@ func NewRepoContext() {
// Repository contains information of a repository.
type Repository struct {
- ID int64
- OwnerID int64 `xorm:"UNIQUE(s)"`
- Owner *User `xorm:"-" json:"-"`
- LowerName string `xorm:"UNIQUE(s) INDEX NOT NULL"`
- Name string `xorm:"INDEX NOT NULL"`
- Description string `xorm:"VARCHAR(512)"`
- Website string
- DefaultBranch string
- Size int64 `xorm:"NOT NULL DEFAULT 0"`
-
+ ID int64
+ OwnerID int64 `xorm:"UNIQUE(s)"`
+ Owner *User `xorm:"-" json:"-"`
+ LowerName string `xorm:"UNIQUE(s) INDEX NOT NULL"`
+ Name string `xorm:"INDEX NOT NULL"`
+ Description string `xorm:"VARCHAR(512)"`
+ Website string
+ DefaultBranch string
+ Size int64 `xorm:"NOT NULL DEFAULT 0"`
+ UseCustomAvatar bool
+
+ // Counters
NumWatches int
NumStars int
NumForks int
@@ -302,10 +307,10 @@ func (repo *Repository) RelAvatarLink() string {
if !com.IsExist(repo.CustomAvatarPath()) {
return defaultImgUrl
}
- return setting.AppSubURL + "/repo-avatars/" + com.ToStr(repo.ID)
+ return fmt.Sprintf("%s/%s/%d", setting.AppSubURL, REPO_AVATAR_URL_PREFIX, repo.ID)
}
// AvatarLink returns user avatar absolute link.
func (repo *Repository) AvatarLink() string {
link := repo.RelAvatarLink()
if link[0] == '/' && link[1] != '/' {
@@ -315,24 +320,23 @@ func (repo *Repository) AvatarLink() string {
}
// UploadAvatar saves custom avatar for repository.
-// FIXME: split uploads to different subdirs
-// in case we have massive number of repositories.
+// FIXME: split uploads to different subdirs in case we have massive number of repositories.
func (repo *Repository) UploadAvatar(data []byte) error {
img, _, err := image.Decode(bytes.NewReader(data))
if err != nil {
- return fmt.Errorf("Decode: %v", err)
+ return fmt.Errorf("decode image: %v", err)
}
- m := resize.Resize(avatar.AVATAR_SIZE, avatar.AVATAR_SIZE, img, resize.NearestNeighbor)
os.MkdirAll(setting.RepositoryAvatarUploadPath, os.ModePerm)
fw, err := os.Create(repo.CustomAvatarPath())
if err != nil {
- return fmt.Errorf("Create: %v", err)
+ return fmt.Errorf("create custom avatar directory: %v", err)
}
defer fw.Close()
+ m := resize.Resize(avatar.AVATAR_SIZE, avatar.AVATAR_SIZE, img, resize.NearestNeighbor)
if err = png.Encode(fw, m); err != nil {
- return fmt.Errorf("Encode: %v", err)
+ return fmt.Errorf("encode image: %v", err)
}
return nil
@@ -341,7 +345,12 @@ func (repo *Repository) UploadAvatar(data []byte) error {
// DeleteAvatar deletes the repository custom avatar.
func (repo *Repository) DeleteAvatar() error {
log.Trace("DeleteAvatar [%d]: %s", repo.ID, repo.CustomAvatarPath())
- return os.Remove(repo.CustomAvatarPath())
+ if err := os.Remove(repo.CustomAvatarPath()); err != nil {
+ return err
+ }
+
+ repo.UseCustomAvatar = false
+ return UpdateRepository(repo, false)
}
// This method assumes following fields have been assigned with valid values:
@@ -372,8 +381,8 @@ func (repo *Repository) APIFormat(permission *api.Permission, user ...*User) *ap
Created: repo.Created,
Updated: repo.Updated,
Permissions: permission,
-// Reserved for go-gogs-client change
-// AvatarUrl: repo.AvatarLink(),
+ // Reserved for go-gogs-client change
+ // AvatarUrl: repo.AvatarLink(),
}
if repo.IsFork {
p := &api.Permission{Pull: true}
@@ -302,10 +307,10 @@ func (repo *Repository) RelAvatarLink() string {
}
-// AvatarLink returns user avatar absolute link.
+// AvatarLink returns repository avatar absolute link.
func (repo *Repository) AvatarLink() string {
link := repo.RelAvatarLink()